(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51694,       1046]*)
(*NotebookOutlinePosition[     52366,       1069]*)
(*  CellTagsIndexPosition[     52322,       1065]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CycleFunctions", "Title"],

Cell[TextData[StyleBox["Copyright (c)  2006, 2008 Kerry Kim\nPermission is \
granted to copy, distribute and/or modify this document under the terms of \
the GNU Free Documentation License, Version 1.2 or any later version \
published by the Free Software Foundation; with no Invariant Sections, no \
Front-Cover Texts, and no Back-Cover Texts.  A copy of the license is \
included in the section entitled \"GNU Free Documentation License\"",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"],

Cell[CellGroupData[{

Cell["About this file:", "Section"],

Cell[TextData[{
  "This file contains all of the functions that came with the lab 5 notebook \
that we used to analyze our gene network oscillator.  These are coped to this \
notebook in the spaces below, with nicely-formatted separators between the \
functions.  \n\n",
  StyleBox["Mathematica", "Input",
    FontSlant->"Italic"],
  " will generate an .m file from this notebook which contains selected \
function definitions that can be easily loaded into the kernel by the \
command",
  StyleBox[" << ", "Input"],
  StyleBox["\"CycleFunctions.m\"", "Input"],
  ".  To do this, we mark the cells we want put into an .m file as \
\"initialization cells\".  This tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to copy the contents of the cell into the m file.  To mark a cell as an \
\"initialization cell\", select the cell by clicking on its blue bracket to \
the right, and select Cell->Cell Properties->Initialization cell in the main \
menu at the top of the screen.  \n\nWhen a cells marked as an initialization \
cell, the blue bracket to the right changes very slightly to have a vertical \
bar coming off the top triangle. Look at the two cells below:\n"
}], "Text"],

Cell[BoxData[
    \( (*This\ is\ NOT\ an\ initializtion\ cell . \ \ This\ is\ the\ normal\ \
cell\ you' 
        ve\ been\ seeing\ up\ until\ this\ point . \ \ It\ has\ a\ single\ \
triangle\ in\ the\ upper\ corner\ of\ the\ bracket\ to\ the\ right*) \)], \
"Input"],

Cell[BoxData[
    \( (*This\ IS\ an\ initialization\ cell . \ \ Look\ at\ the\ slight\ \
change\ to\ the\ bracket\ to\ the\ right*) \)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Whenever you save this notebook, the corresponding .m file is updated with \
any changes that have occured in any of the initialization cells.\n\nYou can \
add your own functions to this file which can then be reloaded into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " whenever we reload ",
  StyleBox["CycleFunctions.m", "Input"],
  ".  To do this, add your code, then mark the cell as an initialization \
cell, THEN SAVE THE FILE.  The .m file is only updated after you save this \
notebook.  \n\nFor readibillity, I've included comments that describe what \
each function does and how to use it in the the text before the actual \
function definitions.  It's a good habit to both comment your code and have a \
summary of what the code does and how to use it.  Follow the format shown \
here when you're adding your own functions to your \"library\" here.\n\nYou \
should copy your ",
  StyleBox["FindWorkingParamSets", "Input"],
  " function from lab 5 to this notebook (there's a placeholder for it near \
the end of this notebook).  "
}], "Text"],

Cell[TextData[{
  "In general, it's a good idea to add functions to this file only after \
you've got them working elsewhere.  If you try to develop functions in this \
notebook, you'll constantly be having to save this notebook, then reload the \
.m file into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text"],

Cell["\<\
One last thing:  Don't use this notebook to do calculations.  Just \
save your useful functions here, and load the corresponding .m file in \
notebooks where you are doing scratch work.  Try to keep this one neat so you \
can easily find your function definitions and fix them if they have bugs.  \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model initialization functions:", "Section"],

Cell[CellGroupData[{

Cell["InitModel [ ]", "Subsection"],

Cell["\<\
Takes no arguments
Clears & resets the cycle oscillator
Equations are stored in global variable cycle
Parameter values and initial conditions are set to values that produce \
oscillations
Dependent variables are stored in dependentvariables\
\>", "Text"],

Cell[BoxData[
    \(\(InitModel = 
        Module[{}, \[IndentingNewLine] (*Clear\ our\ parameter\ \
\(\(values\)\(:\)\)*) \[IndentingNewLine]Clear[HACT, HACTp, As, kTa, nuTa, 
              Pmax, kAt, nuAt, Ts, Htar, HTAR, 
              Tmax]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ our\ \
initial\ \(\(values\)\(:\)\)*) \[IndentingNewLine]Clear[ACTinit, ACTpinit, 
              tarinit, 
              TARinit]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ our\ \
dependent\ \(\(variables\)\(:\)\)*) \[IndentingNewLine]Clear[ACT, ACTp, tar, 
              TAR]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ our\ \
independent\ variable\ and\ system\ of\ \(\(equations\)\(:\)\)\
*) \[IndentingNewLine]Clear[cycle, 
              t]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ the\ end\ \
of\ \(\(integration\)\(:\)\)*) \[IndentingNewLine]Clear[
              tend]; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
 (*Define\ our\ \(\(system\)\(:\)\)*) \[IndentingNewLine]cycle\  = \ \
{\(ACT'\)[t] == ConstantSynthesis[As] - Degredation[ACT[t], HACT] - 
                    Phosphorylation[ACT[t], TAR[t], kTa, nuTa, 
                      Pmax], \[IndentingNewLine]\(ACTp'\)[t] == 
                  Phosphorylation[ACT[t], TAR[t], kTa, nuTa, Pmax] - 
                    Degredation[ACTp[t], HACTp], \[IndentingNewLine]\(tar'\)[
                    t] \[Equal] 
                  Transcription[ACT[t] + ACTp[t], kAt, nuAt, Ts] - 
                    Degredation[tar[t], Htar], \[IndentingNewLine]\(TAR'\)[
                    t] \[Equal] 
                  Translation[tar[t], Tmax] - 
                    Degredation[TAR[t], HTAR], \[IndentingNewLine]ACT[
                    0] \[Equal] ACTinit, \[IndentingNewLine]ACTp[0] \[Equal] 
                  ACTpinit, \[IndentingNewLine]tar[0] \[Equal] 
                  tarinit, \[IndentingNewLine]TAR[0] \[Equal] 
                  TARinit}; \
\[IndentingNewLine]\[IndentingNewLine]dependentvariables = {ACT[t], ACTp[t], 
                tar[t], 
                TAR[t]}; \[IndentingNewLine]\[IndentingNewLine] (*Assign\ \
reasonable\ initial\ values\ to\ our\ \(\(paramters\)\(:\)\)\
*) \[IndentingNewLine]HACT = 60; HACTp = 5; Htar = 20; 
            HTAR = 20; \  (*Half\ lives*) \[IndentingNewLine]\
\[IndentingNewLine]kTa = 0.5; nuTa = 4; 
            Pmax = 1;  (*Phosphorylation\ parameters*) \[IndentingNewLine]\
\[IndentingNewLine]kAt = 0.5; nuAt = 4; 
            Ts = 1/Htar;  (*tar\ transcription\ parameters\
*) \[IndentingNewLine]\[IndentingNewLine]Tmax = 
              1/HTAR;  (*TAR\ translation\ parameters*) \[IndentingNewLine]\
\[IndentingNewLine] (*ACT\ synthesis\ \
\(\(rate\)\(:\)\)*) \[IndentingNewLine]As = 
              1/HACT; \[IndentingNewLine]\[IndentingNewLine]ACTinit = \
\(ACTpinit = \(tarinit = \(TARinit = 
                    0\)\)\);  (*Initial\ conditions*) \[IndentingNewLine]\
\[IndentingNewLine] (*Finally, \ 
              let' s\ set\ the\ end\ time\ of\ integration\ here\ to\ \
something\ \(\(reasonable\)\(:\)\)*) \[IndentingNewLine]tend\  = \ 
              1000;\[IndentingNewLine]] &;\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["InitAffectors [ ]", "Subsection"],

Cell["\<\
Takes no arguments
Clears and resets all affector functions\
\>", "Text"],

Cell[BoxData[
    \(\(InitAffectors = 
        Module[{}, \[IndentingNewLine] (*Clear\ our\ affectors\ then\ define\ \
\(\(them\)\(:\)\)*) \[IndentingNewLine]\[IndentingNewLine]Clear[Degredation, 
              Phi, Phosphorylation, ConstantSynthesis, Transcription, 
              Translation]; \[IndentingNewLine]Degredation[molecule_, 
                halflife_] := 
              molecule/halflife; \[IndentingNewLine]Phi[protein_, k_, nu_] := 
              protein^nu/\((k^nu + 
                    protein^nu)\); \[IndentingNewLine]Phosphorylation[
                substrate_, kinase_, Kkinase_, nukinase_, maximalrate_] := 
              maximalrate\ substrate\ Phi[kinase, Kkinase, 
                  nukinase]; \[IndentingNewLine]ConstantSynthesis[rate_] := 
              rate; \[IndentingNewLine]Transcription[activator_, Kactivator_, 
                nuactivator_, maxrate_] := 
              Phi[activator, Kactivator, nuactivator] 
                maxrate; \[IndentingNewLine]Translation[mRNA_, 
                translationrate_] := 
              mRNA\ translationrate;\[IndentingNewLine]] &;\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for solving, scoring and graphing", "Section"],

Cell[CellGroupData[{

Cell["SolveCycle [ ]", "Subsection"],

Cell[TextData[{
  "Takes no arguments\nCalls ",
  StyleBox["NDSolve", "Input"],
  " to solve the oscillator system\nRequries that ",
  StyleBox["cycle", "Input"],
  ", dependent variables, and ",
  StyleBox["tend", "Input"],
  " be set\nReturns the solution of these equations"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[SolveCycle];\)\), "\[IndentingNewLine]", 
    \(\(SolveCycle[] := 
        NDSolve[cycle, dependentvariables, {t, 0, tend}, 
          MaxSteps \[Rule] Round[20  tend]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotCycle [solution to oscillator network]", "Subsection"],

Cell[TextData[{
  "Takes the solution from ",
  StyleBox["SolveCycle", "Input"],
  " as only argument\nMakes a nicely-formatted plot of ACT[t]+",
  "ACT",
  "p[t] and TAR[t] on same graph from time 0 to tend."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[PlotCycle];\)\), "\[IndentingNewLine]", 
    \(\(PlotCycle = 
        Module[{}, \[IndentingNewLine]\(Plot[
                Evaluate[{ACT[t] + ACTp[t], TAR[t]} /. #1], {t, 0, tend}, 
                PlotRange \[Rule] {0, 1}, 
                AxesLabel \[Rule] {"\<t\>", "\<Conc\>"}, 
                PlotStyle \[Rule] {Red, Black}, 
                PlotLabel -> "\<ACT red, TAR Black\>"];\)\[IndentingNewLine]] \
&;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["PhasePlotCycle [solution to oscillator network]", "Subsection"],

Cell[TextData[{
  "Takes the solution from ",
  StyleBox["SolveCycle", "Input"],
  " as only argument\nMakes a nicely-formatted phase plot of ACT[t]+",
  "ACT",
  "p[t] versus TAR[t] from time 0 to tend."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[PhasePlotCycle];\)\), "\[IndentingNewLine]", 
    \(\(PhasePlotCycle = 
        Module[{}, \[IndentingNewLine]\(ParametricPlot[
                Evaluate[{ACT[t] + ACTp[t], TAR[t]} /. #1], {t, 0, tend}, 
                PlotRange \[Rule] {{0, 1}, {0, 1}}, 
                AxesLabel \[Rule] {"\<ACT\>", "\<TAR\>"}];\)\
\[IndentingNewLine]] &;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ScoreCycle [solution to oscillator network]", "Subsection"],

Cell[TextData[{
  "Takes the solution from ",
  StyleBox["SolveCycle", "Input"],
  " as only argument\nCalls ScoreFunction (see below) and returns the scores \
for the total ACT (ACT + ",
  "ACT",
  "p) and TAR"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ScoreCycle];\)\), "\[IndentingNewLine]", 
    \(\(ScoreCycle = 
        Module[{}, \[IndentingNewLine] (*Start\ by\ solving\ the\ \
\(\(system\)\(:\)\)*) \[IndentingNewLine]\(Return[{ScoreFunction[#1, 
                    ACT[t] + ACTp[t]], ScoreFunction[sol, TAR[t]]}, 
                Module];\)\[IndentingNewLine]] &;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ScoreFunction [solution to oscillator network, dependent variables \
to score]\
\>", "Subsection"],

Cell[TextData[{
  "Takes the solution from ",
  StyleBox["SolveCycle", "Input"],
  " and dependent variables to score for oscillations as arguments.\nDetects \
whether the dependent variables seem to oscillate.  \nReturns data in the \
following format:\n{",
  StyleBox["True", "Input"],
  " if oscillations detected otherwise ",
  StyleBox["False", "Input"],
  ",\nPeak value of last oscillation,\nValley value of last oscillation,\n\
Period of last oscillation}"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ScoreFunction];\)\), "\[IndentingNewLine]", 
    \(\(ScoreFunction = 
        Module[{sol, var, localmaximavalues, localmaximatimes, 
              localminimavalues, localminimatimes, i, oscillates, maxvalue, 
              minvalue, 
              period}, \[IndentingNewLine]sol\  = \ #1; \
\[IndentingNewLine]var\  = \ #2; \[IndentingNewLine]\[IndentingNewLine] \
(*Start\ by\ converting\ our\ solution\ to\ a\ time\ plot\ with\ the\ points\ \
exactly\ 1\ \(\(apart\)\(:\)\)*) \[IndentingNewLine]value\  = \ 
              Flatten[Table[
                  Evaluate[var /. sol], {t, 0, 
                    tend}]]; \[IndentingNewLine]\[IndentingNewLine] \
(*Strategy : \ \ find\ all\ the\ minima\ and\ maxima, \ \(\(starting\ from\ \
the\ end\ and\ going\ backwards\ to\ tend/
                    2\)\(:\)\)*) \[IndentingNewLine]localmaximavalues\  = \ \
{}; \[IndentingNewLine]localmaximatimes = {}; \
\[IndentingNewLine]localminimavalues\  = \ {}; \
\[IndentingNewLine]localminimatimes = {}; \[IndentingNewLine]For[
              i = tend - 1, 
              i > tend/
                  2, \(--i\), {\[IndentingNewLine]\[IndentingNewLine] (*Test\ \
for\ local\ maximum . \ \ If\ it\ is\ local\ max\ then\ record\ time\ and\ \
value*) \[IndentingNewLine]If[
                  value[\([i]\)] > value[\([i + 1]\)] && 
                    value[\([i]\)] > 
                      value[\([i - 1]\)], {\[IndentingNewLine]AppendTo[
                      localmaximavalues, 
                      value[\([i]\)]]; \[IndentingNewLine]AppendTo[
                      localmaximatimes, 
                      i];\[IndentingNewLine]}]; \[IndentingNewLine]\
\[IndentingNewLine] (*Test\ for\ local\ minimum . \ \ If\ it\ is\ local\ min\ \
then\ record\ time\ and\ value*) \[IndentingNewLine]If[
                  value[\([i]\)] < value[\([i + 1]\)] && 
                    value[\([i]\)] < 
                      value[\([i - 1]\)], {\[IndentingNewLine]AppendTo[
                      localminimavalues, 
                      value[\([i]\)]]; \[IndentingNewLine]AppendTo[
                      localminimatimes, 
                      i];\[IndentingNewLine]}];\[IndentingNewLine]}]; \
\[IndentingNewLine]\[IndentingNewLine] (*The\ variables\ below\ are\ going\ \
to\ be\ returned\ by\ our\ score\ function . \ \ For\ now, \ 
              we\ assume\ we\ didn' t\ get\ oscillations . \ \ We' 
                
                ll\ change\ these\ if\ there\ are\ oscillations\ detected\
*) \[IndentingNewLine]oscillates = False; \[IndentingNewLine]maxvalue = 
              0; \[IndentingNewLine]minvalue = 0; \[IndentingNewLine]period = 
              0; \[IndentingNewLine]\[IndentingNewLine] (*Assume\ we\ have\ \
oscillations\ if\ we\ have\ at\ least\ 2\ maxima\ and\ 2\ local\ minima\ in\ \
the\ last\ half\ of\ our\ run*) \[IndentingNewLine]If[
              Length[localmaximavalues] \[GreaterEqual] 2 && 
                Length[localminimavalues] \[GreaterEqual] 
                  2, \[IndentingNewLine]{\[IndentingNewLine] (*Also\ require\ \
that\ the\ maximum\ must\ be\ at\ least\ 1  %\ higher\ than\ the\ minimum\ \
and\ the\ period\ is\ longer\ than\ 4\ time\ units*) \[IndentingNewLine]\(If[
                    localmaximavalues[\([1]\)]/localminimavalues[\([1]\)] > 
                        1.01 && localmaximatimes[\([1]\)] - 
                          localmaximatimes[\([2]\)] > 
                        4, {\[IndentingNewLine]maxvalue = 
                        localmaximavalues[\([1]\)];  (*Last\ peak\ is\ the\ \
maximum*) \[IndentingNewLine]minvalue = 
                        localminimavalues[\([1]\)];  (*Last\ valley\ is\ the\ \
minimum*) \[IndentingNewLine]period = 
                        localmaximatimes[\([1]\)] - 
                          localmaximatimes[\([2]\)];  (*Period\ is\ the\ time\
\ between\ the\ last\ and\ second\ to\ last\ \
maxima*) \[IndentingNewLine]oscillates = 
                        True;\[IndentingNewLine]}];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]Return[{oscillates, maxvalue, minvalue, period}, 
              Module];\[IndentingNewLine]] &;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrintScore [scores of ACT and TAR from ScoreCycle]", "Subsection"],

Cell[TextData[{
  "Prints nicely-formatted results of ",
  StyleBox["ScoreCycle", "Input"],
  ".  \nTakes a single argument as input, which is the score returned by ",
  StyleBox["ScoreCycle", "Input"]
}], "Text"],

Cell[BoxData[{
    \(\(Clear[PrintScore];\)\), "\[IndentingNewLine]", 
    \(\(PrintScore = 
        Module[{ACTscore, 
              TARscore}, \[IndentingNewLine]{ACTscore, 
                TARscore} = #1; \[IndentingNewLine]Print["\<ACT+ACTp:  \
oscillates=\>" <> ToString[ACTscore[\([1]\)]] <> "\<, peak value = \>" <> 
                ToString[ACTscore[\([2]\)]] <> "\<, valley value = \>" <> \ 
                ToString[ACTscore[\([3]\)]] <> "\<, period = \>" <> 
                ToString[
                  ACTscore[\([4]\)]]]; \[IndentingNewLine]Print["\<TAR:      \
oscillates=\>" <> ToString[TARscore[\([1]\)]] <> "\<, peak value = \>" <> 
                ToString[TARscore[\([2]\)]] <> "\<, valley value = \>" <> \ 
                ToString[TARscore[\([3]\)]] <> "\<, period = \>" <> 
                ToString[
                  TARscore[\([4]\)]]];\[IndentingNewLine]] &;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for manipulating parameter sets:", "Section"],

Cell[CellGroupData[{

Cell["Linsamp [minimum, maximum]", "Subsection"],

Cell["Returns a random number between minimum and maximum", "Text"],

Cell[BoxData[{
    \(\(Clear[\ Linsamp];\)\), "\[IndentingNewLine]", 
    \(\(Linsamp[min_, max_] := min + \((max - min)\) Random[];\)\)}], "Input",\

  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
RandomParameterSet [1 = dimensional parameter values, 2 = \
nondimensional parameter values]\
\>", "Subsection"],

Cell["\<\
Takes a single number as an argument and randomizes all parameters \
(but NOT initial conditions) for the oscillator model.
1 = dimensional parameter set 
2 = nondimensional parameter set
This function CHANGES parameter values\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[RandomParameterSet];\)\), "\[IndentingNewLine]", 
    \(\(RandomParameterSet = 
        Module[{}, \[IndentingNewLine]Hmin\  = \ 
              10; \[IndentingNewLine]Hmax\  = \ 
              120; \[IndentingNewLine]kmin\  = \ 
              0.025; \[IndentingNewLine]kmax\  = \ 
              1.2; \[IndentingNewLine]numin\  = \ 
              1; \[IndentingNewLine]numax\  = \ 
              8; \[IndentingNewLine]\[IndentingNewLine]If[#1 \[Equal] 
                1, {\[IndentingNewLine] (*Dimensional\ parameter\ values . \ \
\ We' re\ varying\ all\ parameters\ over\ a\ wide\ \
range*) \[IndentingNewLine]HACT = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HACTp = 
                  Linsamp[0.1  HACT, 
                    0.2  HACT]; \  (*Constrain\ search\ so\ that\ ACTp\ is\ \
degraded\ faster\ than\ ACT*) \[IndentingNewLine]Htar = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HTAR = 
                  Linsamp[Hmin, 
                    Hmax]; \[IndentingNewLine]\[IndentingNewLine]Pmax = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kTa = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kAt = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]nuTa = 
                  Linsamp[numin, numax]; \[IndentingNewLine]nuAt = 
                  Linsamp[numin, 
                    numax]; \[IndentingNewLine]\[IndentingNewLine]Ts = 
                  1/Linsamp[Hmin, Hmax]; \[IndentingNewLine]Tmax = 
                  1/Linsamp[Hmin, Hmax]; \[IndentingNewLine]As = 
                  1/Linsamp[Hmin, 
                      Hmax];\[IndentingNewLine]}]; \[IndentingNewLine]\
\[IndentingNewLine]If[#1 \[Equal] 
                2, {\[IndentingNewLine] (*Effectively\ nondimensionalized . \ \
\ Groupings\ between\ prameter\ values\ chosen\ so\ that\ ACT\ and\ TAR\ vary\
\ from\ 0\ to\ 1\ only . \ \ In\ this\ case\ Ts\ Tmax\ and\ As\ are\ redunant\
\ parameters\ and\ so\ we\ can\ just\ fix\ their\ values\ in\ relation\ to\ \
the\ half\ lives\ and\ still\ explore\ the\ full\ dynamics\ of\ this\ network \
. \ \ Thus\ we\ get\ rid\ of\ 3\ redundant\ values\ and\ only\ have\ to\ \
randomize\ 9\ parameters\ instead\ of\ 12. \ *) \[IndentingNewLine]HACT = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HACTp = 
                  Linsamp[0.1  HACT, 
                    0.2  HACT]; \  (*Constrain\ search\ so\ that\ ACTp\ is\ \
degraded\ faster\ than\ ACT*) \[IndentingNewLine]Htar = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HTAR = 
                  Linsamp[Hmin, 
                    Hmax]; \[IndentingNewLine]\[IndentingNewLine]Pmax = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kTa = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kAt = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]nuTa = 
                  Linsamp[numin, numax]; \[IndentingNewLine]nuAt = 
                  Linsamp[numin, 
                    numax]; \[IndentingNewLine]\[IndentingNewLine]Ts = 
                  1/Htar; \[IndentingNewLine]Tmax = 
                  1/HTAR; \[IndentingNewLine]As = 
                  1/HACT;\[IndentingNewLine]}];\[IndentingNewLine]] &;\)\)}], \
"Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadParamValues [ ]", "Subsection"],

Cell[TextData[{
  "Takes no arguments\nReturns a list with all of the current parameter \
values in the following order:  ",
  StyleBox["H", "Input"],
  "ACT",
  StyleBox[",H", "Input"],
  "ACT",
  StyleBox["p,", "Input"],
  "As",
  StyleBox[",", "Input"],
  "kTa",
  StyleBox[",", "Input"],
  "nuTa",
  StyleBox[",Pmax,", "Input"],
  "kAt",
  StyleBox[",", "Input"],
  "nuAt",
  StyleBox[",", "Input"],
  "Ts",
  StyleBox[",H", "Input"],
  "tar",
  StyleBox[",H", "Input"],
  "TAR",
  StyleBox[",", "Input"],
  "Tmax\nDoes NOT change parameter values"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ReadParamValues];\)\), "\[IndentingNewLine]", 
    \(\(ReadParamValues[] := {HACT, HACTp, As, kTa, nuTa, Pmax, kAt, nuAt, 
          Ts, Htar, HTAR, Tmax};\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["WriteParamValues [list containing all parameter values]", "Subsection"],

Cell[TextData[{
  "Takes a single list as an argument, and sets parameter values according to \
that list.  \nOrder of parameter values in the list must be same as ",
  StyleBox["ReadParamValues", "Input"],
  ": ",
  StyleBox["H", "Input"],
  "ACT",
  StyleBox[", H", "Input"],
  "ACT",
  StyleBox["p, ", "Input"],
  "As",
  StyleBox[", ", "Input"],
  "kTa",
  StyleBox[", ", "Input"],
  "nuTa",
  StyleBox[", Pmax, ", "Input"],
  "kAt",
  StyleBox[", ", "Input"],
  "nuAt",
  StyleBox[", ", "Input"],
  "Ts",
  StyleBox[", H", "Input"],
  "tar",
  StyleBox[", H", "Input"],
  "TAR",
  StyleBox[", ", "Input"],
  "Tmax\nDoes CHANGE parameter values"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[WriteParamValues];\)\), "\[IndentingNewLine]", 
    \(\(WriteParamValues = 
        Module[{}, \[IndentingNewLine]\({HACT, HACTp, As, kTa, nuTa, Pmax, 
                  kAt, nuAt, Ts, Htar, HTAR, 
                  Tmax} = #1;\)\[IndentingNewLine]] &;\)\), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrintParamValues [list containing all parameter values]", "Subsection"],

Cell[TextData[{
  "Takes a single list as an argument, and prints the values in a \
nicely-formatted way.  \nOrder of parameter values in the list must be same \
as ",
  StyleBox["ReadParamValues", "Input"],
  ": ",
  StyleBox["H", "Input"],
  "ACT",
  StyleBox[", H", "Input"],
  "ACT",
  StyleBox["p, ", "Input"],
  "As",
  StyleBox[", ", "Input"],
  "kTa",
  StyleBox[", ", "Input"],
  "nuTa",
  StyleBox[", Pmax, ", "Input"],
  "kAt",
  StyleBox[", ", "Input"],
  "nuAt",
  StyleBox[", ", "Input"],
  "Ts",
  StyleBox[", H", "Input"],
  "tar",
  StyleBox[", H", "Input"],
  "TAR",
  StyleBox[", ", "Input"],
  "Tmax\nDoes NOT change parameter values"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[PrintParamValues];\)\), "\[IndentingNewLine]", 
    \(\(PrintParamValues = 
        Module[{HACT, HACTp, As, kTa, nuTa, Pmax, kAt, nuAt, Ts, Htar, HTAR, 
              Tmax}, \[IndentingNewLine]\[IndentingNewLine] (*We\ want\ this\ \
function\ NOT\ to\ change\ the\ parameter\ values\ \((just\ print\ them)\), 
              so\ we\ define\ new\ local\ copies\ of\ our\ \
\(\(parameters\)\(.\)\)*) \[IndentingNewLine]\[IndentingNewLine]{HACT, HACTp, 
                As, kTa, nuTa, Pmax, kAt, nuAt, Ts, Htar, HTAR, 
                Tmax} = #1; \[IndentingNewLine]\[IndentingNewLine] (*Now, \ 
              print\ a\ nicely - 
                formatted\ table\ of\ our\ values\ and\ a\ legend . \ \ See\ \
TableForm\ help\ for\ more\ \(\(info\)\(.\)\)*) \[IndentingNewLine]Print[
              TableForm[{{"\<HACT\>", "\<HACTp\>", "\<As\>", "\<kTa\>", \
"\<nuTa\>", "\<Pmax\>", "\<kAt\>", "\<nuAt\>", "\<Ts\>", "\<Htar\>", \
"\<HTAR\>", "\<Tmax\>"}, {HACT, HACTp, As, kTa, nuTa, Pmax, kAt, nuAt, Ts, 
                    Htar, HTAR, 
                    Tmax}}]];\[IndentingNewLine]] &;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindWorkingParamSets [number of sets to find]", "Subsection"],

Cell["\<\
Takes a single argument;  the number of sets to find
This function CHANGES parameter values
This function stores all working parameter sets (i.e. that have both ACT and \
TAR oscillations) and the scores. 
Returns working sets in the format {working parameter set list, corresponding \
score for each parameter set}\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[FindWorkingParamSets];\)\), "\[IndentingNewLine]", 
    \(\(FindWorkingParamSets = 
        Module[{}, \[IndentingNewLine]numsets\  = #1; \
\[IndentingNewLine]numfound = 0; \[IndentingNewLine]workingsets = 
              Table[{}, {numsets}]; \[IndentingNewLine]workingscores = 
              Table[{}, {numsets}]; \[IndentingNewLine]While[
              numfound < 
                numsets, \
\[IndentingNewLine]{\[IndentingNewLine]RandomParameterSet[
                  2]; \[IndentingNewLine]sol = 
                  SolveCycle[]; \[IndentingNewLine]score\  = \ 
                  ScoreCycle[sol]; \[IndentingNewLine]\[IndentingNewLine]If[
                  score[\([1, 1]\)] \[Equal] True\  && \ 
                    score[\([2, 1]\)] \[Equal] 
                      True, {\[IndentingNewLine]\(++numfound\); \
\[IndentingNewLine]workingsets[\([numfound]\)] = 
                      ReadParamValues[]; \
\[IndentingNewLine]workingscores[\([numfound]\)] = 
                      score;\[IndentingNewLine]}];\[IndentingNewLine]}]; \
\[IndentingNewLine]Return[{workingsets, workingscores}, 
              Module];\[IndentingNewLine]] &;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other:", "Section"],

Cell[TextData[{
  "The line below causes the string ",
  StyleBox["\"Loaded CycleFunctions.m\"", "Input"],
  " to be printed when CycleFunctions.m is loaded to give feedback to user \
that load was successful."
}], "Text"],

Cell[BoxData[
    \(\(Print["\<Loaded CycleFunctions.m\>"];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["GNU Free Documentation License\nTo view, Double click \
on the arrow to the right (2nd vertical blue line from the right edge, the \
one with the triangle at the bottom) --->",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Section"],

Cell[TextData[StyleBox["\t\tGNU Free Documentation License\n\t\t  Version \
1.2, November 2002\n\n\n Copyright (C) 2000,2001,2002  Free Software \
Foundation, Inc.\n     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  \
USA\n Everyone is permitted to copy and distribute verbatim copies\n of this \
license document, but changing it is not allowed.\n\n\n0. PREAMBLE\n\nThe \
purpose of this License is to make a manual, textbook, or other\nfunctional \
and useful document \"free\" in the sense of freedom: to\nassure everyone the \
effective freedom to copy and redistribute it,\nwith or without modifying it, \
either commercially or noncommercially.\nSecondarily, this License preserves \
for the author and publisher a way\nto get credit for their work, while not \
being considered responsible\nfor modifications made by others.\n\nThis \
License is a kind of \"copyleft\", which means that derivative\nworks of the \
document must themselves be free in the same sense.  It\ncomplements the GNU \
General Public License, which is a copyleft\nlicense designed for free \
software.\n\nWe have designed this License in order to use it for manuals for \
free\nsoftware, because free software needs free documentation: a free\n\
program should come with manuals providing the same freedoms that the\n\
software does.  But this License is not limited to software manuals;\nit can \
be used for any textual work, regardless of subject matter or\nwhether it is \
published as a printed book.  We recommend this License\nprincipally for \
works whose purpose is instruction or reference.\n\n\n1. APPLICABILITY AND \
DEFINITIONS\n\nThis License applies to any manual or other work, in any \
medium, that\ncontains a notice placed by the copyright holder saying it can \
be\ndistributed under the terms of this License.  Such a notice grants a\n\
world-wide, royalty-free license, unlimited in duration, to use that\nwork \
under the conditions stated herein.  The \"Document\", below,\nrefers to any \
such manual or work.  Any member of the public is a\nlicensee, and is \
addressed as \"you\".  You accept the license if you\ncopy, modify or \
distribute the work in a way requiring permission\nunder copyright law.\n\nA \
\"Modified Version\" of the Document means any work containing the\nDocument \
or a portion of it, either copied verbatim, or with\nmodifications and/or \
translated into another language.\n\nA \"Secondary Section\" is a named \
appendix or a front-matter section of\nthe Document that deals exclusively \
with the relationship of the\npublishers or authors of the Document to the \
Document's overall subject\n(or to related matters) and contains nothing that \
could fall directly\nwithin that overall subject.  (Thus, if the Document is \
in part a\ntextbook of mathematics, a Secondary Section may not explain any\n\
mathematics.)  The relationship could be a matter of historical\nconnection \
with the subject or with related matters, or of legal,\ncommercial, \
philosophical, ethical or political position regarding\nthem.\n\nThe \
\"Invariant Sections\" are certain Secondary Sections whose titles\nare \
designated, as being those of Invariant Sections, in the notice\nthat says \
that the Document is released under this License.  If a\nsection does not fit \
the above definition of Secondary then it is not\nallowed to be designated as \
Invariant.  The Document may contain zero\nInvariant Sections.  If the \
Document does not identify any Invariant\nSections then there are none.\n\n\
The \"Cover Texts\" are certain short passages of text that are listed,\nas \
Front-Cover Texts or Back-Cover Texts, in the notice that says that\nthe \
Document is released under this License.  A Front-Cover Text may\nbe at most \
5 words, and a Back-Cover Text may be at most 25 words.\n\nA \"Transparent\" \
copy of the Document means a machine-readable copy,\nrepresented in a format \
whose specification is available to the\ngeneral public, that is suitable for \
revising the document\nstraightforwardly with generic text editors or (for \
images composed of\npixels) generic paint programs or (for drawings) some \
widely available\ndrawing editor, and that is suitable for input to text \
formatters or\nfor automatic translation to a variety of formats suitable for \
input\nto text formatters.  A copy made in an otherwise Transparent file\n\
format whose markup, or absence of markup, has been arranged to thwart\nor \
discourage subsequent modification by readers is not Transparent.\nAn image \
format is not Transparent if used for any substantial amount\nof text.  A \
copy that is not \"Transparent\" is called \"Opaque\".\n\nExamples of \
suitable formats for Transparent copies include plain\nASCII without markup, \
Texinfo input format, LaTeX input format, SGML\nor XML using a publicly \
available DTD, and standard-conforming simple\nHTML, PostScript or PDF \
designed for human modification.  Examples of\ntransparent image formats \
include PNG, XCF and JPG.  Opaque formats\ninclude proprietary formats that \
can be read and edited only by\nproprietary word processors, SGML or XML for \
which the DTD and/or\nprocessing tools are not generally available, and the\n\
machine-generated HTML, PostScript or PDF produced by some word\nprocessors \
for output purposes only.\n\nThe \"Title Page\" means, for a printed book, \
the title page itself,\nplus such following pages as are needed to hold, \
legibly, the material\nthis License requires to appear in the title page.  \
For works in\nformats which do not have any title page as such, \"Title \
Page\" means\nthe text near the most prominent appearance of the work's \
title,\npreceding the beginning of the body of the text.\n\nA section \
\"Entitled XYZ\" means a named subunit of the Document whose\ntitle either is \
precisely XYZ or contains XYZ in parentheses following\ntext that translates \
XYZ in another language.  (Here XYZ stands for a\nspecific section name \
mentioned below, such as \"Acknowledgements\",\n\"Dedications\", \
\"Endorsements\", or \"History\".)  To \"Preserve the Title\"\nof such a \
section when you modify the Document means that it remains a\nsection \
\"Entitled XYZ\" according to this definition.\n\nThe Document may include \
Warranty Disclaimers next to the notice which\nstates that this License \
applies to the Document.  These Warranty\nDisclaimers are considered to be \
included by reference in this\nLicense, but only as regards disclaiming \
warranties: any other\nimplication that these Warranty Disclaimers may have \
is void and has\nno effect on the meaning of this License.\n\n\n2. VERBATIM \
COPYING\n\nYou may copy and distribute the Document in any medium, either\n\
commercially or noncommercially, provided that this License, the\ncopyright \
notices, and the license notice saying this License applies\nto the Document \
are reproduced in all copies, and that you add no other\nconditions \
whatsoever to those of this License.  You may not use\ntechnical measures to \
obstruct or control the reading or further\ncopying of the copies you make or \
distribute.  However, you may accept\ncompensation in exchange for copies.  \
If you distribute a large enough\nnumber of copies you must also follow the \
conditions in section 3.\n\nYou may also lend copies, under the same \
conditions stated above, and\nyou may publicly display copies.\n\n\n3. \
COPYING IN QUANTITY\n\nIf you publish printed copies (or copies in media that \
commonly have\nprinted covers) of the Document, numbering more than 100, and \
the\nDocument's license notice requires Cover Texts, you must enclose the\n\
copies in covers that carry, clearly and legibly, all these Cover\nTexts: \
Front-Cover Texts on the front cover, and Back-Cover Texts on\nthe back \
cover.  Both covers must also clearly and legibly identify\nyou as the \
publisher of these copies.  The front cover must present\nthe full title with \
all words of the title equally prominent and\nvisible.  You may add other \
material on the covers in addition.\nCopying with changes limited to the \
covers, as long as they preserve\nthe title of the Document and satisfy these \
conditions, can be treated\nas verbatim copying in other respects.\n\nIf the \
required texts for either cover are too voluminous to fit\nlegibly, you \
should put the first ones listed (as many as fit\nreasonably) on the actual \
cover, and continue the rest onto adjacent\npages.\n\nIf you publish or \
distribute Opaque copies of the Document numbering\nmore than 100, you must \
either include a machine-readable Transparent\ncopy along with each Opaque \
copy, or state in or with each Opaque copy\na computer-network location from \
which the general network-using\npublic has access to download using \
public-standard network protocols\na complete Transparent copy of the \
Document, free of added material.\nIf you use the latter option, you must \
take reasonably prudent steps,\nwhen you begin distribution of Opaque copies \
in quantity, to ensure\nthat this Transparent copy will remain thus \
accessible at the stated\nlocation until at least one year after the last \
time you distribute an\nOpaque copy (directly or through your agents or \
retailers) of that\nedition to the public.\n\nIt is requested, but not \
required, that you contact the authors of the\nDocument well before \
redistributing any large number of copies, to give\nthem a chance to provide \
you with an updated version of the Document.\n\n\n4. MODIFICATIONS\n\nYou may \
copy and distribute a Modified Version of the Document under\nthe conditions \
of sections 2 and 3 above, provided that you release\nthe Modified Version \
under precisely this License, with the Modified\nVersion filling the role of \
the Document, thus licensing distribution\nand modification of the Modified \
Version to whoever possesses a copy\nof it.  In addition, you must do these \
things in the Modified Version:\n\nA. Use in the Title Page (and on the \
covers, if any) a title distinct\n   from that of the Document, and from \
those of previous versions\n   (which should, if there were any, be listed in \
the History section\n   of the Document).  You may use the same title as a \
previous version\n   if the original publisher of that version gives \
permission.\nB. List on the Title Page, as authors, one or more persons or \
entities\n   responsible for authorship of the modifications in the Modified\n\
   Version, together with at least five of the principal authors of the\n   \
Document (all of its principal authors, if it has fewer than five),\n   \
unless they release you from this requirement.\nC. State on the Title page \
the name of the publisher of the\n   Modified Version, as the publisher.\nD. \
Preserve all the copyright notices of the Document.\nE. Add an appropriate \
copyright notice for your modifications\n   adjacent to the other copyright \
notices.\nF. Include, immediately after the copyright notices, a license \
notice\n   giving the public permission to use the Modified Version under the\
\n   terms of this License, in the form shown in the Addendum below.\nG. \
Preserve in that license notice the full lists of Invariant Sections\n   and \
required Cover Texts given in the Document's license notice.\nH. Include an \
unaltered copy of this License.\nI. Preserve the section Entitled \
\"History\", Preserve its Title, and add\n   to it an item stating at least \
the title, year, new authors, and\n   publisher of the Modified Version as \
given on the Title Page.  If\n   there is no section Entitled \"History\" in \
the Document, create one\n   stating the title, year, authors, and publisher \
of the Document as\n   given on its Title Page, then add an item describing \
the Modified\n   Version as stated in the previous sentence.\nJ. Preserve the \
network location, if any, given in the Document for\n   public access to a \
Transparent copy of the Document, and likewise\n   the network locations \
given in the Document for previous versions\n   it was based on.  These may \
be placed in the \"History\" section.\n   You may omit a network location for \
a work that was published at\n   least four years before the Document itself, \
or if the original\n   publisher of the version it refers to gives \
permission.\nK. For any section Entitled \"Acknowledgements\" or \
\"Dedications\",\n   Preserve the Title of the section, and preserve in the \
section all\n   the substance and tone of each of the contributor \
acknowledgements\n   and/or dedications given therein.\nL. Preserve all the \
Invariant Sections of the Document,\n   unaltered in their text and in their \
titles.  Section numbers\n   or the equivalent are not considered part of the \
section titles.\nM. Delete any section Entitled \"Endorsements\".  Such a \
section\n   may not be included in the Modified Version.\nN. Do not retitle \
any existing section to be Entitled \"Endorsements\"\n   or to conflict in \
title with any Invariant Section.\nO. Preserve any Warranty Disclaimers.\n\n\
If the Modified Version includes new front-matter sections or\nappendices \
that qualify as Secondary Sections and contain no material\ncopied from the \
Document, you may at your option designate some or all\nof these sections as \
invariant.  To do this, add their titles to the\nlist of Invariant Sections \
in the Modified Version's license notice.\nThese titles must be distinct from \
any other section titles.\n\nYou may add a section Entitled \"Endorsements\", \
provided it contains\nnothing but endorsements of your Modified Version by \
various\nparties--for example, statements of peer review or that the text has\
\nbeen approved by an organization as the authoritative definition of a\n\
standard.\n\nYou may add a passage of up to five words as a Front-Cover Text, \
and a\npassage of up to 25 words as a Back-Cover Text, to the end of the list\
\nof Cover Texts in the Modified Version.  Only one passage of\nFront-Cover \
Text and one of Back-Cover Text may be added by (or\nthrough arrangements \
made by) any one entity.  If the Document already\nincludes a cover text for \
the same cover, previously added by you or\nby arrangement made by the same \
entity you are acting on behalf of,\nyou may not add another; but you may \
replace the old one, on explicit\npermission from the previous publisher that \
added the old one.\n\nThe author(s) and publisher(s) of the Document do not \
by this License\ngive permission to use their names for publicity for or to \
assert or\nimply endorsement of any Modified Version.\n\n\n5. COMBINING \
DOCUMENTS\n\nYou may combine the Document with other documents released under \
this\nLicense, under the terms defined in section 4 above for modified\n\
versions, provided that you include in the combination all of the\nInvariant \
Sections of all of the original documents, unmodified, and\nlist them all as \
Invariant Sections of your combined work in its\nlicense notice, and that you \
preserve all their Warranty Disclaimers.\n\nThe combined work need only \
contain one copy of this License, and\nmultiple identical Invariant Sections \
may be replaced with a single\ncopy.  If there are multiple Invariant \
Sections with the same name but\ndifferent contents, make the title of each \
such section unique by\nadding at the end of it, in parentheses, the name of \
the original\nauthor or publisher of that section if known, or else a unique \
number.\nMake the same adjustment to the section titles in the list of\n\
Invariant Sections in the license notice of the combined work.\n\nIn the \
combination, you must combine any sections Entitled \"History\"\nin the \
various original documents, forming one section Entitled\n\"History\"; \
likewise combine any sections Entitled \"Acknowledgements\",\nand any \
sections Entitled \"Dedications\".  You must delete all sections\nEntitled \
\"Endorsements\".\n\n\n6. COLLECTIONS OF DOCUMENTS\n\nYou may make a \
collection consisting of the Document and other documents\nreleased under \
this License, and replace the individual copies of this\nLicense in the \
various documents with a single copy that is included in\nthe collection, \
provided that you follow the rules of this License for\nverbatim copying of \
each of the documents in all other respects.\n\nYou may extract a single \
document from such a collection, and distribute\nit individually under this \
License, provided you insert a copy of this\nLicense into the extracted \
document, and follow this License in all\nother respects regarding verbatim \
copying of that document.\n\n\n7. AGGREGATION WITH INDEPENDENT WORKS\n\nA \
compilation of the Document or its derivatives with other separate\nand \
independent documents or works, in or on a volume of a storage or\n\
distribution medium, is called an \"aggregate\" if the copyright\nresulting \
from the compilation is not used to limit the legal rights\nof the \
compilation's users beyond what the individual works permit.\nWhen the \
Document is included in an aggregate, this License does not\napply to the \
other works in the aggregate which are not themselves\nderivative works of \
the Document.\n\nIf the Cover Text requirement of section 3 is applicable to \
these\ncopies of the Document, then if the Document is less than one half of\n\
the entire aggregate, the Document's Cover Texts may be placed on\ncovers \
that bracket the Document within the aggregate, or the\nelectronic equivalent \
of covers if the Document is in electronic form.\nOtherwise they must appear \
on printed covers that bracket the whole\naggregate.\n\n\n8. TRANSLATION\n\n\
Translation is considered a kind of modification, so you may\ndistribute \
translations of the Document under the terms of section 4.\nReplacing \
Invariant Sections with translations requires special\npermission from their \
copyright holders, but you may include\ntranslations of some or all Invariant \
Sections in addition to the\noriginal versions of these Invariant Sections.  \
You may include a\ntranslation of this License, and all the license notices \
in the\nDocument, and any Warranty Disclaimers, provided that you also \
include\nthe original English version of this License and the original \
versions\nof those notices and disclaimers.  In case of a disagreement \
between\nthe translation and the original version of this License or a notice\
\nor disclaimer, the original version will prevail.\n\nIf a section in the \
Document is Entitled \"Acknowledgements\",\n\"Dedications\", or \"History\", \
the requirement (section 4) to Preserve\nits Title (section 1) will typically \
require changing the actual\ntitle.\n\n\n9. TERMINATION\n\nYou may not copy, \
modify, sublicense, or distribute the Document except\nas expressly provided \
for under this License.  Any other attempt to\ncopy, modify, sublicense or \
distribute the Document is void, and will\nautomatically terminate your \
rights under this License.  However,\nparties who have received copies, or \
rights, from you under this\nLicense will not have their licenses terminated \
so long as such\nparties remain in full compliance.\n\n\n10. FUTURE REVISIONS \
OF THIS LICENSE\n\nThe Free Software Foundation may publish new, revised \
versions\nof the GNU Free Documentation License from time to time.  Such new\n\
versions will be similar in spirit to the present version, but may\ndiffer in \
detail to address new problems or concerns.  See\n\
http://www.gnu.org/copyleft/.\n\nEach version of the License is given a \
distinguishing version number.\nIf the Document specifies that a particular \
numbered version of this\nLicense \"or any later version\" applies to it, you \
have the option of\nfollowing the terms and conditions either of that \
specified version or\nof any later version that has been published (not as a \
draft) by the\nFree Software Foundation.  If the Document does not specify a \
version\nnumber of this License, you may choose any version ever published \
(not\nas a draft) by the Free Software Foundation.\n\n\nADDENDUM: How to use \
this License for your documents\n\nTo use this License in a document you have \
written, include a copy of\nthe License in the document and put the following \
copyright and\nlicense notices just after the title page:\n\n    Copyright \
(c)  YEAR  YOUR NAME.\n    Permission is granted to copy, distribute and/or \
modify this document\n    under the terms of the GNU Free Documentation \
License, Version 1.2\n    or any later version published by the Free Software \
Foundation;\n    with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.\n    A copy of the license is included in the section \
entitled \"GNU\n    Free Documentation License\".\n\nIf you have Invariant \
Sections, Front-Cover Texts and Back-Cover Texts,\nreplace the \
\"with...Texts.\" line with this:\n\n    with the Invariant Sections being \
LIST THEIR TITLES, with the\n    Front-Cover Texts being LIST, and with the \
Back-Cover Texts being LIST.\n\nIf you have Invariant Sections without Cover \
Texts, or some other\ncombination of the three, merge those two alternatives \
to suit the\nsituation.\n\nIf your document contains nontrivial examples of \
program code, we\nrecommend releasing these examples in parallel under your \
choice of\nfree software license, such as the GNU General Public License,\nto \
permit their use in free software.\n",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1625}, {0, 1028}},
AutoGeneratedPackage->Automatic,
WindowSize->{520, 740},
WindowMargins->{{Automatic, 304}, {Automatic, 96}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 31, 0, 88, "Title"],
Cell[1810, 55, 499, 7, 174, "Text"],

Cell[CellGroupData[{
Cell[2334, 66, 35, 0, 69, "Section"],
Cell[2372, 68, 1193, 22, 259, "Text"],
Cell[3568, 92, 266, 5, 91, "Input"],
Cell[3837, 99, 173, 3, 43, "Input",
  InitializationCell->True],
Cell[4013, 104, 1085, 19, 273, "Text"],
Cell[5101, 125, 343, 8, 64, "Text"],
Cell[5447, 135, 323, 6, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5807, 146, 50, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[5882, 150, 35, 0, 38, "Subsection"],
Cell[5920, 152, 264, 7, 94, "Text"],
Cell[6187, 161, 3161, 53, 1051, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[9385, 219, 39, 0, 38, "Subsection"],
Cell[9427, 221, 83, 3, 46, "Text"],
Cell[9513, 226, 1151, 19, 363, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10713, 251, 62, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[10800, 255, 36, 0, 38, "Subsection"],
Cell[10839, 257, 289, 8, 80, "Text"],
Cell[11131, 267, 242, 5, 75, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[11410, 277, 64, 0, 38, "Subsection"],
Cell[11477, 279, 221, 6, 63, "Text"],
Cell[11701, 287, 488, 10, 139, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[12226, 302, 69, 0, 38, "Subsection"],
Cell[12298, 304, 216, 6, 63, "Text"],
Cell[12517, 312, 414, 8, 123, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[12968, 325, 65, 0, 38, "Subsection"],
Cell[13036, 327, 223, 7, 63, "Text"],
Cell[13262, 336, 393, 7, 107, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[13692, 348, 108, 3, 56, "Subsection"],
Cell[13803, 353, 476, 11, 144, "Text"],
Cell[14282, 366, 4174, 70, 1355, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[18493, 441, 72, 0, 38, "Subsection"],
Cell[18568, 443, 213, 5, 48, "Text"],
Cell[18784, 450, 927, 16, 315, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19760, 472, 61, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[19846, 476, 48, 0, 38, "Subsection"],
Cell[19897, 478, 67, 0, 30, "Text"],
Cell[19967, 480, 178, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[20182, 489, 122, 3, 56, "Subsection"],
Cell[20307, 494, 250, 6, 94, "Text"],
Cell[20560, 502, 3254, 55, 1003, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[23851, 562, 41, 0, 38, "Subsection"],
Cell[23895, 564, 564, 25, 80, "Text"],
Cell[24462, 591, 228, 4, 75, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[24727, 600, 77, 0, 38, "Subsection"],
Cell[24807, 602, 661, 27, 97, "Text"],
Cell[25471, 631, 361, 8, 107, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[25869, 644, 77, 0, 38, "Subsection"],
Cell[25949, 646, 666, 28, 97, "Text"],
Cell[26618, 676, 1159, 18, 395, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[27814, 699, 67, 0, 38, "Subsection"],
Cell[27884, 701, 339, 7, 110, "Text"],
Cell[28226, 710, 1209, 22, 379, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29484, 738, 25, 0, 69, "Section"],
Cell[29512, 740, 222, 5, 63, "Text"],
Cell[29737, 747, 102, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[29876, 754, 260, 4, 119, "Section"],
Cell[30139, 760, 21527, 282, 7974, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

