(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     96402,       2215]*)
(*NotebookOutlinePosition[     97062,       2238]*)
(*  CellTagsIndexPosition[     97018,       2234]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Lab 5: Searching Parameter space", "Title"],

Cell[TextData[StyleBox["Copyright (c)  2006, 2008 Kerry Kim, Jonathan \
Alberts, Garrett Odell, George von Dassow, and Edwin Munro\nPermission is \
granted to copy, distribute and/or modify this document under the terms of \
the GNU Free Documentation License, Version 1.2 or any later version \
published by the Free Software Foundation; with no Invariant Sections, no \
Front-Cover Texts, and no Back-Cover Texts.  A copy of the license is \
included in the section entitled \"GNU Free Documentation License\"",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"],

Cell[CellGroupData[{

Cell["Overview:", "Section"],

Cell[TextData[{
  "In the previous labs, you've seen that the behavior of models depends \
strongly upon the parameter values and the initial conditions.  The behavior \
of the models and their ability to reproduce biologically observed behavior \
depends strongly on these values. Unfortunately, most of these quantitative \
parameters upon which the models behavior depends so strongly have not been \
measured and are unknown.  So, computational models must first find parameter \
values that reproduce the target behavior, and then see how individual \
parameters affect the model.\n\nIn today's lab, you'll learn how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to systematically explore the effects of changing parameter values.  To \
do this requries you to do some more traditional programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "Another way of defining ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions:"
}], "Subsection"],

Cell["\<\
Shown below is a function that takes a number, and returns one plus \
that number:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[AddOne];\)\), "\[IndentingNewLine]", 
    \(\(AddOne = 
        Module[{}, \[IndentingNewLine]n = #1; \[IndentingNewLine]result\  = \ 
              n\  + \ 1; \[IndentingNewLine]Return[result, 
              Module];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[BoxData[
    \(AddOne[5]\)], "Input"],

Cell[TextData[{
  "You could easily replace the ",
  StyleBox["AddOne", "Input"],
  " function with something much simpler (i.e. ",
  StyleBox["AddOne[n_]:=n+1", "Input"],
  " does the exact same thing in one fifth the space).  But for the sake of \
illustration, this is how to use some of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s more powerful features.  Let's dissect the ",
  StyleBox["AddOne", "Input"],
  " function line-by-line.\n\nThe first line starts the ",
  StyleBox["Module", "Input"],
  " command.  The ",
  StyleBox["Module", "Input"],
  " command allows us to have a single function execute many commands one \
after another.  Ignore the ",
  StyleBox["{}", "Input"],
  " that follows ",
  StyleBox["Module", "Input"],
  " for now, we'll return to this later.\n\nThe next line (",
  StyleBox["n=#1", "Input"],
  ") is also a little different.  It says to set ",
  StyleBox["n", "Input"],
  " to the first argument of ",
  StyleBox["AddOne", "Input"],
  ".  In other words, when you later type ",
  StyleBox["AddOne[5]", "Input"],
  ", ",
  StyleBox["n", "Input"],
  " is set to ",
  StyleBox["5", "Input"],
  ". \n\nAfter ",
  StyleBox["n", "Input"],
  " is defined, ",
  StyleBox["result", "Input"],
  " is set to ",
  StyleBox["n + 1", "Input"],
  ", which is pretty straightforward.  Then, we have the statement ",
  StyleBox["Return[result,Module]", "Input"],
  ".  This says this function should return the value of ",
  StyleBox["result", "Input"],
  ".  The ",
  StyleBox[",Module", "Input"],
  " is simply there to indicate that we're retruning from the ",
  StyleBox["Module", "Input"],
  " command.  Finally, the ",
  StyleBox["Module", "Input"],
  " command is closed with a bracket, and we have a ",
  StyleBox["&", "Input"],
  ";.  The ",
  StyleBox["&", "Input"],
  " tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that we have defined a function (rather than using a",
  StyleBox[" :=", "Input"],
  ").  This is a little strange, but you'll get used to it.  Here's another \
example that adds two numbers together:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[AddTogether];\)\), "\[IndentingNewLine]", 
    \(\(AddTogether = 
        Module[{}, \[IndentingNewLine]x\  = \ #1; \[IndentingNewLine]y\  = \
#2; \[IndentingNewLine]Return[x\  + \ y, \ 
              Module]\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[BoxData[
    \(AddTogether[5, 4]\)], "Input"],

Cell[TextData[{
  "Again, when after we define our function and type ",
  StyleBox["AddTogether[5,4]", "Input"],
  ",",
  StyleBox[" x", "Input"],
  " is set to the first argument (in this case 5) and ",
  StyleBox["y", "Input"],
  " is set to the second argument (4).  The function returns their sum (of \
9)."
}], "Text"],

Cell["\<\
You could also have accomplished the same thing by using this \
definition:\
\>", "Text"],

Cell[BoxData[
    \(\(AddTogether2[x_, y_] := x + y;\)\)], "Input"],

Cell[BoxData[
    \(AddTogether2[5, 4]\)], "Input"],

Cell[TextData[{
  "So, you know two ways of accomplishing the same thing.  We have a compact \
way of defining simple functions using the ",
  StyleBox["AddTogether[x_,y_] :=", "Input"],
  " notation, and a longer way using the Module method. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The difference between = and :=", "Subsection"],

Cell[TextData[{
  "There is an important distinction to make when defining a function with \
the:=sign and the=sign.  The following example will hopefully illuminate \
this.  Suppose we have a function called ",
  StyleBox["EvaluateRightNow[x] ", "Input"],
  "that takes an argument and increases a global variable by that amount, \
,and another function called ",
  StyleBox["EvaluateWhenFunctionCalled[x]", "Input"],
  " that does the same thing,but uses the single equals sign:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[counter, x];\)\), "\[IndentingNewLine]", 
    \(\(counter\  = \ 5;\)\), "\[IndentingNewLine]", 
    \(\(EvaluateRightNow[x_] = \((counter += x)\);\)\)}], "Input"],

Cell[BoxData[
    \(EvaluateRightNow[9]\)], "Input"],

Cell[BoxData[
    \(EvaluateRightNow[9]\)], "Input"],

Cell[TextData[{
  "If you use the ",
  StyleBox["EvaluateRightNow", "Input"],
  " command twice in a row, it will act as if counter is always 5.  This is \
because we've used a single equals sing which immediatly replces counter with \
5 in the function definition, so even if counter is changed to a new value, \
",
  StyleBox["EvaluateRightNow", "Input"],
  " just takes 5 and adds ",
  StyleBox["x", "Input"],
  " to it.  Let's compare this behavior to the following:"
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(counter\  = \ 5;\)\[IndentingNewLine]
    \(EvaluateWhenFunctionCalled[
          x_] := \ \((counter += x)\);\)\)\)\)], "Input"],

Cell[BoxData[
    \(EvaluateWhenFunctionCalled[9]\)], "Input"],

Cell[TextData[{
  "Now note that each successive call to ",
  StyleBox["EvaluateWhenFunctionCalled", "Input"],
  " looks up the current value of ",
  StyleBox["counter", "Input"],
  " and increases it by ",
  StyleBox["x", "Input"],
  ".  The key distinction between the ",
  StyleBox["=", "Input"],
  " and ",
  StyleBox[":=", "Input"],
  " has to do with when the right hand side is evaluated.  With the single ",
  StyleBox["=", "Input"],
  " sign, the right hand side is evaluated only when the function is defined. \
 With the ",
  StyleBox[":=", "Input"],
  ", the function recalculates the right hand side each time the function is \
called.  If you're still confused about this, ask your classmates or your \
instructors for clarification."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Writing a function to determine if a number is prime:", "Subsection"],

Cell[TextData[{
  "Let's now write a nontrivial function that shows the power of using \
functions defined using the ",
  StyleBox["Module", "Input"],
  " command:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[IsPrime];\)\), "\[IndentingNewLine]", 
    \(\(IsPrime = 
        Module[{}, \[IndentingNewLine]n\  = \ #1; \[IndentingNewLine]For[
              i = 2, i \[LessEqual] 
                Sqrt[n], \(++i\), {\[IndentingNewLine]\(If[
                    Mod[n, i] \[Equal] 
                      0, \[IndentingNewLine]{\[IndentingNewLine]\(Return[
                          False, 
                          Module];\)\[IndentingNewLine]}];\)\
\[IndentingNewLine]}]; \[IndentingNewLine]Return[True, 
              Module];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[BoxData[
    \(IsPrime[5]\)], "Input"],

Cell[TextData[{
  "This function tells you whether an integer greater than 2 is prime or not. \
 How does it work?  The function then checks to see whether your number is \
evenly divisible by any integer from 2, 3, etc up to the square root of your \
number.  If it is, then we know your number isn't prime; otherwise it is.  \n\
\nThe new thing in this function is the Mod and If commands.  The Mod command \
takes 2 numbers, and calculates the remainder after dividing the first by the \
second.  The If statement checks to see whether Mod[n,i] is equal to 0 (we \
use the double equals sign here to indicate a test of equality--asking ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " whether the right hand side equals the left hand side; this is different \
than a single equals sign which assigns one value to another).  If this the \
number is evenly divisible, then we know it's not prime and immediatly return \
False. \n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The If Statement", "Subsection"],

Cell[TextData[{
  "There are a few basic logic and loop structures that are found in nearly \
every program.  With this limited set of statments and a good imagination, \
one can solve extremely complicated problems.  One of these logic structure \
is the If-then-Else statement. \n\nThe general syntax for an ",
  StyleBox["If", "Input"],
  " statement is the following:\n\n",
  StyleBox["If[conditionalStatment,{\n\tdo all the statements enclosed by \
these curly braces if the conditionalStatement is True.\n\t},{\n\tdo all the \
statements enclosed by these curly braces if the conditionalStatement is \
False.\n\t},{\n\tdo all the statements enclosed by these curly braces if the \
conditionalStatement is NEITHER True NOR FALSE.\n}]", "Input"],
  "\n\nWhere the conditionalStatement is some statement that can evaluate to \
True, False, or Neither.\n\t4 < 5\t\t\ta True conditionalStatment\n\t5 < 4\t\t\
\ta False conditionalStatment\n\t(4 / 0) > 5\t\ta Neither True nor False \
statement, as 4/0 does not evaluate to a number.  The Neither segment can be \
a good way to catch errors.\n\t(4<5)&&(6>7)\tThe logical operators && and || \
can be used to make a conditionalStatement based off of two separate \
conditionalStatements\n\t(4<5) || (6>7)\t\tThese can be grouped together in \
complex ways, like\n\t\t\t\t( ((aCondStatement&&aCondStatement) || \
(aCondStatement || aCondStatement))&& aCondStatement)\n\t\nWhere the \"do all \
these statments enclosed by curly braces\" corresponds to a single statment, \
or multiple statements that are separated by semicolons( the last statement \
does not have a semicolon placed after it).  "
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[" ",
        FontSize->18,
        FontWeight->"Bold",
        FontTracking->"Extended",
        Background->None], 
      RowBox[{
        RowBox[{
          StyleBox[\(tempVariable = True\),
            FontSize->12,
            FontWeight->"Bold",
            FontTracking->"Extended",
            Background->None], 
          StyleBox[";",
            FontSize->12,
            FontWeight->"Bold",
            FontTracking->"Extended",
            Background->None]}], 
        StyleBox["\n",
          FontSize->12,
          FontWeight->"Bold",
          FontTracking->"Extended",
          Background->None], 
        StyleBox["  ",
          FontSize->12,
          FontWeight->"Bold",
          FontTracking->"Extended",
          Background->None], 
        RowBox[{
          RowBox[{
            StyleBox["If",
              FontSize->12,
              FontWeight->"Bold",
              FontTracking->"Extended",
              Background->None], 
            StyleBox["[",
              FontSize->12,
              FontWeight->"Bold",
              FontTracking->"Extended",
              Background->None], 
            RowBox[{
              StyleBox["tempVariable",
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None], 
              StyleBox[",",
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None], 
              
              StyleBox[\({\n\ \ \tPrint["\<The conditionalStatement was \
True\>"]\n\ \ }\),
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None], 
              StyleBox[",",
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None], 
              
              StyleBox[\({\n\ \ \tPrint["\<The conditionalStatement was False\
\>"]\n\ \ }\),
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None], 
              StyleBox[",",
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None], 
              
              StyleBox[\({\n\ \ \tPrint["\<The conditionalStatement was \
Neither.\>"]\n\ \ }\),
                FontSize->12,
                FontWeight->"Bold",
                FontTracking->"Extended",
                Background->None]}], 
            StyleBox["]",
              FontSize->12,
              FontWeight->"Bold",
              FontTracking->"Extended",
              Background->None]}], 
          StyleBox[";",
            FontSize->12,
            FontWeight->"Bold",
            FontTracking->"Extended",
            Background->None]}]}]}]], "Input",
  FontSize->9],

Cell[TextData[{
  "You can have ",
  StyleBox["If", "Input"],
  " statement inside of other ",
  StyleBox["If", "Input"],
  " statements--that's perfectly legal, and a common programming construct.  \
Just be sure that you keep track of where each ",
  StyleBox["If", "Input"],
  " statement ends.  Logical Operators perform comparisons or tests that \
evaluate to ",
  StyleBox["True", "Input"],
  ", ",
  StyleBox["False", "Input"],
  ", or ",
  StyleBox["Undetermined", "Input"],
  " (",
  StyleBox["4 < 5", "Input"],
  ", where ",
  StyleBox["<", "Input"],
  " is the test for whether less than).  There are many different Logical \
operators in Mathematica:\n\n\t",
  StyleBox["arg1 == arg2      \"equals\" operator:                        \
True when arg1 equals arg2\n\targ1 != arg2       \"not equals\" operator:     \
              True when arg1 does not equal arg2\n\targ1 < arg2        \"Less \
than\" operator:                    True when arg1 is less than arg2\n\targ1 \
> arg2        \"greater than\" operator:                 True when arg1 is \
greater than arg2\n\targ1 <= arg2       \"Less than or equals to\" operator:  \
     True when arg1 is less than or equal to arg2\n\targ1 >=arg2        \
\"Greater than or equals to\" operator:    True when arg1 is greater than or \
equal to arg2\n\t!(arg1)            \"Not\" operator:                      \t\
True when arg1 is false.\n\targ1 && arg2        \"And\" operator:             \
            True only when both arg1 and arg2 are true \n\targ1 ||  arg2      \
  \"Or\" operator:                         True when either arg1 and arg2 are \
true, or both are true ", "Input"],
  "\n\t\nThe test for equality ",
  StyleBox["==", "Input"],
  " differs from the assignment operator = that we use to assign a value to a \
variable.\n\"aVariable = 9\"    means \"make the contents of aVariable be the \
number 9.\"\n\"aVariable == 9\"  means \"are the contents of aVariable equal \
to the number 9?\""
}], "Text"],

Cell[TextData[{
  "Have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluate the code below and it will return either True or False for each \
test.  "
}], "Text"],

Cell[BoxData[{
    StyleBox[\(\(5\  == \ 5\)\(\ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(5\  != \ 8\)\(\ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(10\  < \ 23\)\(\ \ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(10\  > \ 23\)\(\ \ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(10\  <= \ 23\)\(\ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(23\  >= \ 23\)\(\ \ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(! \((5 > 4)\)\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(5\  != \ 8\ \  && \ 10\  < \ 23\)\(\ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None], "\n", 
    StyleBox[\(\(True\)\(\ \)\(||\)\(\ \)\(False\)\(\ \ \ \ \ \ \ \)\),
      FontWeight->"Bold",
      FontTracking->"Extended",
      Background->None]}], "Input"],

Cell["\<\
Now, you can do some useful things.  Here's an example of the If \
command:\
\>", "Text"],

Cell[BoxData[{
    \(\(x\  = \ 10;\)\), "\[IndentingNewLine]", 
    \(\(y = 20;\)\), "\[IndentingNewLine]", 
    \(\(If[
        x < y, \[IndentingNewLine]{\[IndentingNewLine]\(Print["\<x is less \
than y\>"];\)\[IndentingNewLine]}, {\[IndentingNewLine]\(Print["\<x is not \
less than y\>"];\)\[IndentingNewLine]}, {\[IndentingNewLine]\(Print["\<Could \
not determine whether x is less than y\>"];\)\[IndentingNewLine]}];\)\)}], \
"Input"],

Cell["\<\
Look again at the IsPrime function, and realize we have an error in \
our function, also called a \"bug\".  If we use IsPrime to determine whether \
1 is prime, it says it is, even when it isn't:\
\>", "Text"],

Cell[BoxData[
    \(IsPrime[1]\)], "Input"],

Cell[TextData[{
  "Modify the ",
  StyleBox["IsPrime", "Input"],
  " function by adding a single ",
  StyleBox["If", "Input"],
  " statement to fix this."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Review of For loops:", "Subsection"],

Cell[TextData[{
  "The For command lets you repeat a series of steps many times and has the \
following format.  Let's use a For loop to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " count to 10 for us:"
}], "Text"],

Cell[BoxData[
    \(\(For[i = 1, 
        i \[LessEqual] 
          10, \(++i\), {\[IndentingNewLine]\(Print[
              i];\)\[IndentingNewLine]}];\)\)], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["For", "Input"],
  " command has the following format:  ",
  StyleBox["For[initial conditions, test, increment, {body}]", "Input"],
  ".  The flow of execution is first the initial conditions are evaluated, \
then the test.  If the test passes (i.e. evaluates to ",
  StyleBox["True", "Input"],
  "), then the commands in the body are run, followed by the increment.  \
Then, the test is re-evaluated, and if it is ",
  StyleBox["True", "Input"],
  ", the body and increment are run again."
}], "Text"],

Cell["\<\
Here's another example of a For loop, except it prints out the \
numeric value of Pi to more and more significant digits:\
\>", "Text"],

Cell[BoxData[
    \(\(For[numdigits = 1, numdigits \[LessEqual] 64, 
        numdigits *= 
          2, {\[IndentingNewLine]\(Print["\<Pi is aproximately: \>" <> 
                ToString[
                  N[Pi, numdigits]]];\)\[IndentingNewLine]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global variables:", "Subsection"],

Cell[TextData[{
  "So far, whenever we assign a value to something, we're defining a \"Global\
\" variable; the value is available to be modified or read by any function.  \
This can lead to some problems, as shown below:\nWe are going to write a loop \
that uses the ",
  StyleBox["IsPrime", "Input"],
  " function and prints out which of the first 10 integers is prime.  "
}], "Text"],

Cell["\<\
Here is the loop that uses the IsPrime function and prints out \
which of the first 10 integers is prime:\
\>", "Text"],

Cell[BoxData[
    \(\(\( (*This\ command\ should\ produce\ output\ along\ the\ lines\ \(of \
: \[IndentingNewLine]2\ is\ prime\[IndentingNewLine]3\ is\ prime\
\[IndentingNewLine]5\ is\ prime\[IndentingNewLine]7\ is\ prime\
\[IndentingNewLine]but\ it\ doesn' 
            t . \ \ \(\(Why\)\(?\)\)\)*) \)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(\(i = 2;\)\[IndentingNewLine]
    \(For[j = 2, 
        j \[LessEqual] 
          10, \(++j\), \[IndentingNewLine]{\[IndentingNewLine]If[
            IsPrime[i] \[Equal] 
              True, \[IndentingNewLine]{\[IndentingNewLine]\(Print[
                  ToString[
                      i] <> "\< is prime\>"];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]\(i++\);\[IndentingNewLine]}];\)\)\)\)], "Input"],

Cell[TextData[{
  "Can you explain what happened here?  You can verify that nothing is \
obviously wrong with the ",
  StyleBox["IsPrime", "Input"],
  " function by using the command ",
  StyleBox["Table[IsPrime[x],{x,1,10}]", "Input"],
  ".  This should return whether each of the first 10 numbers is prime or \
not.:"
}], "Text"],

Cell[BoxData[
    \(Table[IsPrime[x], {x, 1, 10}]\)], "Input"],

Cell[TextData[{
  "The problem is that we're using ",
  StyleBox["i", "Input"],
  " twice.  In the commands above,",
  StyleBox[" i", "Input"],
  " is supposed to be first 1, then 2, then 3, etc, up to 10.  However, the \
",
  StyleBox["IsPrime", "Input"],
  " command also uses and modifies the variable ",
  StyleBox["i", "Input"],
  ".  As a result, every time we call the ",
  StyleBox["IsPrime", "Input"],
  " command, it sets ",
  StyleBox["i", "Input"],
  " to 2, then we return to the For loop that uses the ",
  StyleBox["IsPrime", "Input"],
  " and ",
  StyleBox["i", "Input"],
  " keeps getting reset instead of stepping from 1 to 10.  If you're still \
confused about this, ask your classmates or instructors/TAs.  We could get \
around this by changing our code so that either our loop or ",
  StyleBox["IsPrime", "Input"],
  " uses a different variable name besides ",
  StyleBox["i", "Input"],
  ", but there's a better solution."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Local variables:", "Subsection"],

Cell[TextData[{
  "We really don't care what goes on with ",
  StyleBox["i", "Input"],
  " and ",
  StyleBox["n", "Input"],
  " inside of ",
  StyleBox["IsPrime", "Input"],
  " and it would be good if we didn't have to keep track of all the variables \
each function uses to avoid name collisions.  An elegant solution is to \
define them as \"local' variables--that is variables that exist only inside \
of the ",
  StyleBox["IsPrime", "Input"],
  " function.  We would like the ",
  StyleBox["i", "Input"],
  " inside ",
  StyleBox["IsPrime", "Input"],
  " to NOT affect ",
  StyleBox["i", "Input"],
  " elsewhere.  \n\nTo do this, we enclose the names of the local variables \
in the list at the beginning of the ",
  StyleBox["IsPrime", "Input"],
  " function as follows:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[IsPrime2];\)\), "\[IndentingNewLine]", 
    \(\(IsPrime2 = 
        Module[{i, n}, \[IndentingNewLine]n\  = \ #1; \[IndentingNewLine]For[
              i = 2, i \[LessEqual] 
                Sqrt[n], \(++i\), {\[IndentingNewLine]\(If[
                    Mod[n, i] \[Equal] 
                      0, \[IndentingNewLine]{\[IndentingNewLine]\(Return[
                          False, 
                          Module];\)\[IndentingNewLine]}];\)\
\[IndentingNewLine]}]; \[IndentingNewLine]Return[True, 
              Module];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[TextData[{
  "Now, compare the behavior of ",
  StyleBox["IsPrime", "Input"],
  " to ",
  StyleBox["IsPrime2", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\( (*Behavior\ of\ IsPrime*) \)\(\[IndentingNewLine]\)\(\(i = 
        10;\)\[IndentingNewLine]
    \(Print["\<Before IsPrime, i = \>" <> ToString[i]];\)\[IndentingNewLine]
    \(IsPrime[7];\)\[IndentingNewLine]
    \(Print["\<After IsPrime, i = \>" <> \ ToString[i]];\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*Behavior\ of\ IsPrime2\ which\ uses\ a\ local\ variable\ for\ i\
*) \)\(\[IndentingNewLine]\)\(\(i = 10;\)\[IndentingNewLine]
    \(Print["\<Before IsPrime2, i = \>" <> ToString[i]];\)\[IndentingNewLine]
    \(IsPrime2[7];\)\[IndentingNewLine]
    \(Print["\<After IsPrime2, i = \>" <> \ ToString[i]];\)\)\)\)], "Input"],

Cell[TextData[{
  "Any local variables we declare in the ",
  StyleBox["Module", "Input"],
  " are local--that is they exist only inside of ",
  StyleBox["IsPrime2", "Input"],
  " and don't affect the global variables.  Now, try the code below again:"
}], "Text"],

Cell[BoxData[
    \(\(\( (*This\ command\ should\ produce\ output\ along\ the\ lines\ \(of \
: \[IndentingNewLine]2\ is\ prime\[IndentingNewLine]3\ is\ prime\
\[IndentingNewLine]5\ is\ prime\[IndentingNewLine]7\ is\ prime\
\[IndentingNewLine]but\ it\ doesn' 
            t . \ \ \(\(Why\)\(?\)\)\)*) \)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(\(i = 2;\)\[IndentingNewLine]
    \(For[j = 2, 
        j \[LessEqual] 
          10, \(++j\), \[IndentingNewLine]{\[IndentingNewLine]If[
            IsPrime2[i] \[Equal] 
              True, \[IndentingNewLine]{\[IndentingNewLine]\(Print[
                  ToString[
                      i] <> "\< is prime\>"];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]\(i++\);\[IndentingNewLine]}];\)\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Another Example  The Taylor Series approximation of e^x:", "Subsection"],

Cell["\<\
The Taylor Series expansion of e^x about 0 is 1 + x + x^/2 + \
x^3/3!+...x^n/n!.  Let's make a function that returns the value of e^x for by \
summing the first n terms in the Taylor Series expansion:\
\>", "Text"],

Cell[BoxData[
    \(\(TaylorApproximation = 
        Module[{result, taylorseries}, \[IndentingNewLine]result = 
              0; \[IndentingNewLine]\[IndentingNewLine] (*Build\ the\ taylor\ \
series\ expansion\ terms . \ \ #2\ is\ the\ number\ of\ terms\ to\ expand\ \
and\ #1\ is\ the\ value\ to\ expand\ around*) \[IndentingNewLine]taylorseries\
\  = \ Table[#1^term/\(term!\), {term, 
                  0, #2}]; \[IndentingNewLine]\[IndentingNewLine] (*Sum\ the\ \
taylor\ series\ expansion\ terms*) \[IndentingNewLine]For[i = 1, 
              i \[LessEqual] #2, \(++i\), \[IndentingNewLine]{\
\[IndentingNewLine]\(result += 
                    taylorseries[\([i]\)];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]\[IndentingNewLine] (*Return\ the\ result\
*) \[IndentingNewLine]Return[result, 
              Module];\[IndentingNewLine]] &;\)\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will return results wherever possible in exact fractions for maximal \
accuracy:"
}], "Text"],

Cell[BoxData[
    \(TaylorApproximation[1, 10]\)], "Input"],

Cell[TextData[{
  "We can use N on the above to have it convert the fraction into its decimal \
approximation or give it 1.0 as an input (which tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that you're giving it a decimal approximation and to do its calculations \
with decimal approximations):"
}], "Text"],

Cell[BoxData[
    \(TaylorApproximation[1.0, 10]\)], "Input"],

Cell[BoxData[
    \(\(\( (*Give\ us\ the\ first\ 10\ digits\ of\ our\ \(\(result\)\(:\)\)\
*) \)\(\[IndentingNewLine]\)\(N[TaylorApproximation[1, 10], 
      10]\)\)\)], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows how to deal with complex numbers, our function works for imaginary \
numbers:"
}], "Text"],

Cell[BoxData[
    \(\(\( (*Calculate\ \
e^\(\(i\)\(:\)\)*) \)\(\[IndentingNewLine]\)\(TaylorApproximation[1.0  I, 
      10]\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A word on how to make your own functions:", "Subsection"],

Cell[TextData[{
  "When you start building your own functions, you should try first figuring \
out what commands you need to use and in what order.  Don't worry about \
figuring out which variables to declare global or local--keep them all global \
at first so you can see what their values are when the function exits.  Also, \
if you're having problems/bugs, insert ",
  StyleBox["Print", "Input"],
  " statements at strategic locations to help you see the internal logic and \
what's going on.\n\nThe function below calculates the nth number in the \
Fibonacci series.  The Fibonacci series is 1, 1, 2, 3, 5, 8, 13, etc.  Each \
number in the series is the sum of the two previous numbers in the series and \
the first 2 numbers in the series are both 1.  Unfortunately, the function \
has an error in it.  See if you can figure out where it is, then fix it so \
the function works properly:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[Fibo];\)\), "\[IndentingNewLine]", 
    \(\(Fibo = 
        Module[{fiboseries, i}, \[IndentingNewLine]If[#1 \[LessEqual] \ 2, 
              Return[1, Module]]; \[IndentingNewLine]fiboseries = {1, 
                1}; \[IndentingNewLine]For[i = 1, 
              i < #1, \(++i\), \[IndentingNewLine]{\[IndentingNewLine] (*The\ \
AppendTo\ command\ adds\ an\ element\ to\ the\ end\ of\ the\ specified\ list\
*) \[IndentingNewLine]\(AppendTo[fiboseries, 
                    fiboseries[\([\(-1\)]\)] + 
                      fiboseries[\([\(-2\)]\)]];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]Return[fiboseries[\([\(-1\)]\)], 
              Module];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[BoxData[
    \(\(\( (*Should\ give\ 1\ as\ an\ \(\(answer\)\(:\)\)*) \)\(\
\[IndentingNewLine]\)\(Fibo[2]\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*Should\ give\ 5\ as\ an\ \(\(answer\)\(:\)\)*) \)\(\
\[IndentingNewLine]\)\(Fibo[5]\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise:", "Subsection"],

Cell[TextData[{
  "An observation:  Consider the following triplets of sequential integers \
where the first and last are prime numbers:  5,6,7 and 11, 12, 13 and \
17,18,19 and 29,30,31.  In all cases, the middle number is evenly divisible \
by 6.  Is this always the case? (There's a very short proof of this; can \
anyone prove your answer one way or the other?). For now, suppose you take an \
empirical approach.  Write a function that does the following:  It takes 2 \
arguments:  a low number and a high number.  It then considers all integers \
between the low and high numbers and looks for triplets of numbers where the \
first and last numbers are prime.  If the middle number is evenly divisible \
by 6, it should say so, if the number ISN'T evenly divible by 6, it should \
say it's found an exception to our observation (and you should check this by \
hand).\n\nA couple of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " tips that may be helpful depending on how you write your function:  Be \
sure to use ",
  StyleBox["IsPrime2", "Input"],
  " if you want to recycle the above code.  The ",
  StyleBox["Length", "Input"],
  " function returns the length of a list.  If you want to test for multiple \
conditions at a time, ",
  StyleBox["&&", "Input"],
  " indicates logical AND and ",
  StyleBox["||", "Input"],
  " indicates logical OR.  The exclamation indicates logical NOT.  So, if you \
wanted to test something like a is greater than 5 AND b is less than or equal \
to 7, you would write this as ",
  StyleBox["a <5 && b <=7", "Input"],
  ".  Or if you wanted to see whether i is NOT prime, you could use ",
  StyleBox["!IsPrime2[i]", "Input"],
  ", which would return ",
  StyleBox["True", "Input"],
  " if ",
  StyleBox["i", "Input"],
  " is not prime.  \n\nYour function should be named ",
  StyleBox["ProofByExample", "Input"],
  " and produce output similar to that shown below:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ProofByExample[10, 200];\)\)], "Input"],

Cell[BoxData[
    \("In {11, 12, 13} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {17, 18, 19} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {29, 30, 31} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {41, 42, 43} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {59, 60, 61} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {71, 72, 73} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {101, 102, 103} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {107, 108, 109} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {137, 138, 139} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {149, 150, 151} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {179, 180, 181} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {191, 192, 193} middle number IS evenly divisible by 6!"\)], "Print"],

Cell[BoxData[
    \("In {197, 198, 199} middle number IS evenly divisible by 6!"\)], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Automating common modeling tasks:", "Section"],

Cell[CellGroupData[{

Cell["Initializing the system of equations:", "Subsection"],

Cell[TextData[{
  "When you're working with a model, you'll find that there are common tasks \
that you repeat many times:  Defining the model; updating the parameters; \
solving the model; making plots, etc.  Let's return to our oscillator from \
lab #4, and write a function called ",
  StyleBox["InitModel", "Input"],
  " that does the following:  It clears all the variables that need to be \
cleared, defines the system of equations and dependent variables, and assigns \
reasonable initial values to parameters and intial conditions that produce \
oscillations.  Here we go:"
}], "Text"],

Cell[BoxData[
    \(\(InitModel = 
        Module[{}, \[IndentingNewLine] (*Clear\ our\ parameter\ \
\(\(values\)\(:\)\)*) \[IndentingNewLine]Clear[HACT, HACTp, As, kTa, nuTa, 
              Pmax, kAt, nuAt, Ts, Htar, HTAR, 
              Tmax]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ our\ \
initial\ \(\(values\)\(:\)\)*) \[IndentingNewLine]Clear[ACTinit, ACTpinit, 
              tarinit, 
              TARinit]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ our\ \
dependent\ \(\(variables\)\(:\)\)*) \[IndentingNewLine]Clear[ACT, ACTp, tar, 
              TAR]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ our\ \
independent\ variable\ and\ system\ of\ \(\(equations\)\(:\)\)\
*) \[IndentingNewLine]Clear[cycle, 
              t]; \[IndentingNewLine]\[IndentingNewLine] (*Clear\ the\ end\ \
of\ \(\(integration\)\(:\)\)*) \[IndentingNewLine]Clear[
              tend]; \[IndentingNewLine]\[IndentingNewLine] (*Define\ our\ \(\
\(system\)\(:\)\)*) \[IndentingNewLine]cycle\  = \ {\(ACT'\)[t] == 
                  ConstantSynthesis[As] - Degredation[ACT[t], HACT] - 
                    Phosphorylation[ACT[t], TAR[t], kTa, nuTa, 
                      Pmax], \[IndentingNewLine]\(ACTp'\)[t] == 
                  Phosphorylation[ACT[t], TAR[t], kTa, nuTa, Pmax] - 
                    Degredation[ACTp[t], HACTp], \[IndentingNewLine]\(tar'\)[
                    t] \[Equal] 
                  Transcription[ACT[t] + ACTp[t], kAt, nuAt, Ts] - 
                    Degredation[tar[t], Htar], \[IndentingNewLine]\(TAR'\)[
                    t] \[Equal] 
                  Translation[tar[t], Tmax] - 
                    Degredation[TAR[t], HTAR], \[IndentingNewLine]ACT[
                    0] \[Equal] ACTinit, \[IndentingNewLine]ACTp[0] \[Equal] 
                  ACTpinit, \[IndentingNewLine]tar[0] \[Equal] 
                  tarinit, \[IndentingNewLine]TAR[0] \[Equal] 
                  TARinit}; \
\[IndentingNewLine]\[IndentingNewLine]dependentvariables = {ACT[t], ACTp[t], 
                tar[t], TAR[t]}; \[IndentingNewLine]\[IndentingNewLine]HACT = 
              60; HACTp = 5; Htar = 20; 
            HTAR = 20; \  (*Half\ lives*) \[IndentingNewLine]kTa = 0.5; 
            nuTa = 4; 
            Pmax = 1;  (*Phosphorylation\ parameters*) \[IndentingNewLine]kAt \
= 0.5; nuAt = 4; 
            Ts = 1/Htar;  (*tar\ transcription\ parameters\
*) \[IndentingNewLine]Tmax = 
              1/HTAR;  (*TAR\ translation\ \
parameters*) \[IndentingNewLine]ACTinit = \(ACTpinit = \(tarinit = \(TARinit \
= 0\)\)\);  (*Initial\ conditions*) \[IndentingNewLine]As = 
              1/HACT;  (*ACT\ synthesis\ \(\(rate\)\(:\)\)\
*) \[IndentingNewLine]\[IndentingNewLine] (*Finally, \ 
              let' s\ set\ the\ end\ time\ of\ integration\ here\ to\ \
something\ \(\(reasonable\)\(:\)\)*) \[IndentingNewLine]tend\  = \ 
              1000;\[IndentingNewLine]] &;\)\)], "Input"],

Cell[TextData[{
  "Most of the above is copied straight out of lab #4.  Here they all are \
together.  Now, whenever we want to re-initialize our system, we just type ",
  StyleBox["InitModel[].", "Input"],
  " There are no local variables, because we want to keep everything global \
for now.  After this function is run, ",
  StyleBox["cycle", "Input"],
  " contains our system of equations, all the parameter values are set to \
values that support oscillation, and the dependent variables are all put \
together in a list called ",
  StyleBox["dependentvariables", "Input"],
  " for later use with ",
  StyleBox["NDSolve", "Input"],
  ".\n\nNow, let's make a function that sets all our affectors:"
}], "Text"],

Cell[BoxData[
    \(\(InitAffectors = 
        Module[{}, \[IndentingNewLine] (*Clear\ our\ affectors\ then\ define\ \
\(\(them\)\(:\)\)*) \[IndentingNewLine]\[IndentingNewLine]Clear[Degredation, 
              Phi, Phosphorylation, ConstantSynthesis, Transcription, 
              Translation]; \[IndentingNewLine]Degredation[molecule_, 
                halflife_] := 
              molecule/halflife; \[IndentingNewLine]Phi[protein_, k_, nu_] := 
              protein^nu/\((k^nu + 
                    protein^nu)\); \[IndentingNewLine]Phosphorylation[
                substrate_, kinase_, Kkinase_, nukinase_, maximalrate_] := 
              maximalrate\ substrate\ Phi[kinase, Kkinase, 
                  nukinase]; \[IndentingNewLine]ConstantSynthesis[rate_] := 
              rate; \[IndentingNewLine]Transcription[activator_, Kactivator_, 
                nuactivator_, maxrate_] := 
              Phi[activator, Kactivator, nuactivator] 
                maxrate; \[IndentingNewLine]Translation[mRNA_, 
                translationrate_] := 
              mRNA\ translationrate;\[IndentingNewLine]] &;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving & Plotting:", "Subsection"],

Cell[TextData[{
  "Another very common task when you're working with networks is to use ",
  StyleBox["NDSolve", "Input"],
  " then make a useful plot of your system.  Let's do this:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[SolveCycle];\)\), "\[IndentingNewLine]", 
    \(\(SolveCycle[] := 
        NDSolve[cycle, dependentvariables, {t, 0, tend}, 
          MaxSteps \[Rule] Round[20  tend]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[PlotCycle];\)\), "\[IndentingNewLine]", 
    \(\(PlotCycle = 
        Module[{}, \[IndentingNewLine]\(Plot[
                Evaluate[{ACT[t] + ACTp[t], TAR[t]} /. #1], {t, 0, tend}, 
                PlotRange \[Rule] {0, 1}, 
                AxesLabel \[Rule] {"\<t\>", "\<Conc\>"}, 
                PlotStyle \[Rule] {Red, Black}, 
                PlotLabel -> "\<ACT red, TAR Black\>"];\)\[IndentingNewLine]] \
&;\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[PhasePlotCycle];\)\), "\[IndentingNewLine]", 
    \(\(PhasePlotCycle = 
        Module[{}, \[IndentingNewLine]\(ParametricPlot[
                Evaluate[{ACT[t] + ACTp[t], TAR[t]} /. #1], {t, 0, tend}, 
                PlotRange \[Rule] {{0, 1}, {0, 1}}, 
                AxesLabel \[Rule] {"\<ACT\>", "\<TAR\>"}];\)\
\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[TextData[{
  StyleBox["SolveCycle", "Input"],
  " is a function that takes no arguments, but returns the solution to our \
set of equations from 0 to whatever tend currently is.  ",
  StyleBox["PlotCycle", "Input"],
  " takes the solution to our system, and plots the total ACT and the TAR \
versus time in a nicely formatted graph.\n",
  StyleBox["PhasePlotCycle", "Input"],
  " also takes the solution to the system as an argument, then plots total \
ACT against ",
  "TAR",
  " in a nicely formatted graph.\n\nNow, life is much easier:"
}], "Text"],

Cell[BoxData[{
    \(\(InitAffectors[];\)\), "\[IndentingNewLine]", 
    \(\(InitModel[];\)\), "\[IndentingNewLine]", 
    \(\(PlotCycle[SolveCycle[]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweeping across parameter values:", "Subsection"],

Cell["Let's look carefully how parameter values depend on kEc:", "Text"],

Cell[BoxData[
    \(\(\( (*Reset\ our\ model\ so\ we' 
        re\ working\ around\ our\ "\<usual\>"\ parameter\ values*) \)\(\
\[IndentingNewLine]\)\(\(InitAffectors[];\)\[IndentingNewLine]
    \(InitModel[];\)\[IndentingNewLine]
    \(For[kAt = 0.05, kAt < 1.5, 
        kAt += 0.05, \[IndentingNewLine]{\[IndentingNewLine]\(PlotCycle[
              SolveCycle[]];\)\[IndentingNewLine]}];\)\)\)\)], "Input"],

Cell[TextData[{
  "Now, if you double click on the blue bracket to the right of the graphs \
(the second bracket in from the right that \"surrounds\" all the individual \
graphs), all the graphs will be collapsed together into a movie. If you \
double click on the graph now, you can watch a movie of the behavior of the \
oscillator as ",
  StyleBox["kEc", "Input"],
  " changes.  \n\nLikewise, you can easily make a movie of phase plots as you \
sweep across different initial conditions:"
}], "Text"],

Cell[BoxData[
    \(\(\( (*Reset\ our\ model\ so\ we' 
        re\ working\ around\ our\ "\<usual\>"\ parameter\ values*) \)\(\
\[IndentingNewLine]\)\(\(InitAffectors[];\)\[IndentingNewLine]
    \(InitModel[];\)\[IndentingNewLine]
    \(For[i = 1, 
        i \[LessEqual] 
          20, \(++i\), \[IndentingNewLine]{\[IndentingNewLine]ACTinit += 
            0.05; \[IndentingNewLine]TARinit += 
            0.03; \[IndentingNewLine]PhasePlotCycle[
            SolveCycle[]];\[IndentingNewLine]}];\)\)\)\)], "Input"],

Cell["\<\
You could also make a movie of the phase plane progression in time:\
\
\>", "Text"],

Cell[BoxData[
    \(\(\( (*Reset\ our\ model\ so\ we' 
        re\ working\ around\ our\ "\<usual\>"\ parameter\ values*) \)\(\
\[IndentingNewLine]\)\(\(InitAffectors[];\)\[IndentingNewLine]
    \(InitModel[];\)\[IndentingNewLine]
    \(ACTinit = 0.5;\)\[IndentingNewLine]
    \(TARinit = 0.3;\)\[IndentingNewLine]
    \(For[i = 1, 
        i \[LessEqual] 
          30, \(++i\), \[IndentingNewLine]{\[IndentingNewLine]tend = 
            20  i; \[IndentingNewLine]PhasePlotCycle[
            SolveCycle[]];\[IndentingNewLine]}];\)\)\)\)], "Input"],

Cell["\<\
Here's something for you to think about:  We saw in the Turing \
model and switch network that paths in phase space never crossed.  In this \
case, you saw that the trajectory DOES intersect itself, sometimes in many \
points. Why can this happen in this model?\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random parameter searches:", "Section"],

Cell[CellGroupData[{

Cell["Random number distributions:", "Subsection"],

Cell["\<\
Since none of the parameter values in our oscillator are known to \
within an order of magnitude (and the uncertainty is likely to be several \
orders of magnitude), it can be useful to see what other parameter values \
will produce oscillatory behavior.  Let's start by defining a function that \
gives us nicely-distributed random numbers:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[\ Linsamp];\)\), "\[IndentingNewLine]", 
    \(\(Linsamp[min_, max_] := min + \((max - min)\) Random[];\)\)}], "Input"],

Cell["\<\
Let's just see the random distrubtions generated by our \
distributions:\
\>", "Text"],

Cell[BoxData[
    \(\(ListPlot[Table[Linsamp[0.05, 5], {1000}], 
        PlotRange \[Rule] {0.05, 5}];\)\)], "Input"],

Cell["\<\
Now, we have a function that makes nicely distributed random \
numbers in a convenient way.  Next step is to use this to make completely \
random parameter sets; but first a quick review of lists:\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Lists in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (review)"
}], "Subsection"],

Cell[TextData[{
  "When you want to access a specific element of a list, use a double bracket \
pair ",
  StyleBox["[[ ]]", "Input"],
  " to get the specified element of the list:"
}], "Text"],

Cell[BoxData[{
    \(\(squares\  = \ 
        Table[i^2, {i, 1, 
            10}];\)\[IndentingNewLine]\[IndentingNewLine] (*The\ 5  
        th\ number\ in\ the\ squares\ \(\(list\)\(:\)\)*) \), "\
\[IndentingNewLine]", 
    \(squares[\([5]\)]\)}], "Input"],

Cell[BoxData[
    \(\(\( (*The\ last\ number\ in\ the\ squares\ \(list--\) 
        negative\ numbers\ count\ backwards\ from\ the\ last\ element\ in\ \
the\ list*) \)\(\[IndentingNewLine]\)\(squares[\([\(-1\)]\)]\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*the\ regular\ \
\(\(way\)\(:\)\)*) \)\(\[IndentingNewLine]\)\(squares[\([10]\)]\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(\( (*Another\ way\ to\ get\ the\ last\ \(\(number\)\(:\)\)*) \)\(\
\[IndentingNewLine]\)\(squares[\([Length[squares]]\)]\)\)\)], "Input"],

Cell["Our system of equations is stored in a list as well:", "Text"],

Cell[BoxData[
    \(cycle\)], "Input"],

Cell[TextData[{
  "We can pull out specific elements in our system of equations.  Here's how \
we get the 2nd equation in ",
  StyleBox["cycle", "Input"],
  ":"
}], "Text"],

Cell[BoxData[
    \(cycle[\([2]\)]\)], "Input"],

Cell["Lists can contain other lists:", "Text"],

Cell[BoxData[
    \(nestedlists = Table[Table[i + j, {i, 1, 5}], {j, 1, 5}]\)], "Input"],

Cell[TextData[{
  "The second element of ",
  StyleBox["nestedlists", "Input"],
  " is itself a list:"
}], "Text"],

Cell[BoxData[
    \(nestedlists[\([2]\)]\)], "Input"],

Cell[TextData[{
  "If we want the 3rd element of ",
  StyleBox["nestedlists[[2]]", "Input"],
  ", we can do this:"
}], "Text"],

Cell[BoxData[
    \(nestedlists[\([2, 3]\)]\)], "Input"],

Cell[TextData[{
  "The above statement says take the second element from ",
  StyleBox["nestedlists", "Input"],
  " (which is a list) then take the 3rd element from that list."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiple assignment using lists:", "Subsection"],

Cell["\<\
You can use a special syntax that lets you quickly assign multiple \
variables at the same time using the list syntax shown below:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[aa, bb, cc];\)\), "\[IndentingNewLine]", 
    \(\({aa, bb, cc} = {1, 3, 5};\)\), "\[IndentingNewLine]", 
    \(aa\), "\[IndentingNewLine]", 
    \(bb\), "\[IndentingNewLine]", 
    \(cc\)}], "Input"],

Cell["\<\
This notation will be useful as you'll see later in this section.\
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Randomizing parameters:", "Subsection"],

Cell["\<\
The function below randomizes the parameter values across a large \
range, which reflects the approximate reasonable uncertanty in biological \
values.  Call RandomParameterSet[1] for a set of randomzied paramter values, \
and RandomParameterSet[2] to have an effectively nondimensionalized system \
where parameter groupings are chosen so that ACT and TAR will vary between 0 \
and 1.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[RandomParameterSet];\)\), "\[IndentingNewLine]", 
    \(\(RandomParameterSet = 
        Module[{}, \[IndentingNewLine]Hmin\  = \ 
              10; \[IndentingNewLine]Hmax\  = \ 
              120; \[IndentingNewLine]kmin\  = \ 
              0.025; \[IndentingNewLine]kmax\  = \ 
              1.2; \[IndentingNewLine]numin\  = \ 
              1; \[IndentingNewLine]numax\  = \ 
              8; \[IndentingNewLine]\[IndentingNewLine]If[#1 \[Equal] 
                1, {\[IndentingNewLine] (*Dimensional\ parameter\ values . \ \
\ We' re\ varying\ all\ parameters\ over\ a\ wide\ \
range*) \[IndentingNewLine]HACT = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HACTp = 
                  Linsamp[0.1  HACT, 
                    0.2  HACT]; \  (*Constrain\ search\ so\ that\ ACTp\ is\ \
degraded\ faster\ than\ ACT*) \[IndentingNewLine]Htar = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HTAR = 
                  Linsamp[Hmin, 
                    Hmax]; \[IndentingNewLine]\[IndentingNewLine]Pmax = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kTa = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kAt = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]nuTa = 
                  Linsamp[numin, numax]; \[IndentingNewLine]nuAt = 
                  Linsamp[numin, 
                    numax]; \[IndentingNewLine]\[IndentingNewLine]Ts = 
                  1/Linsamp[Hmin, Hmax]; \[IndentingNewLine]Tmax = 
                  1/Linsamp[Hmin, Hmax]; \[IndentingNewLine]As = 
                  1/Linsamp[Hmin, 
                      Hmax];\[IndentingNewLine]}]; \[IndentingNewLine]\
\[IndentingNewLine]If[#1 \[Equal] 
                2, {\[IndentingNewLine] (*Effectively\ nondimensionalized . \ \
\ Groupings\ between\ prameter\ values\ chosen\ so\ that\ ACT\ and\ TAR\ vary\
\ from\ 0\ to\ 1\ only . \ \ In\ this\ case\ Cs\ Cmax\ and\ Es\ are\ redunant\
\ parameters\ and\ so\ we\ can\ just\ fix\ their\ values\ in\ relation\ to\ \
the\ half\ lives\ and\ still\ explore\ the\ full\ dynamics\ of\ this\ network \
. \ \ Thus, \ 
                  we\ get\ rid\ of\ 3\ redundant\ values\ and\ only\ have\ to\
\ randomize\ 9\ parameters\ instead\ of\ 12. \ *) \[IndentingNewLine]HACT = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HACTp = 
                  Linsamp[0.1  HACT, 
                    0.2  HACT]; \  (*Constrain\ search\ so\ that\ ACTp\ is\ \
degraded\ faster\ than\ ACT*) \[IndentingNewLine]Htar = 
                  Linsamp[Hmin, Hmax]; \[IndentingNewLine]HTAR = 
                  Linsamp[Hmin, 
                    Hmax]; \[IndentingNewLine]\[IndentingNewLine]Pmax = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kTa = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]kAt = 
                  Linsamp[kmin, kmax]; \[IndentingNewLine]nuTa = 
                  Linsamp[numin, numax]; \[IndentingNewLine]nuAt = 
                  Linsamp[numin, 
                    numax]; \[IndentingNewLine]\[IndentingNewLine]Ts = 
                  1/Htar; \[IndentingNewLine]Tmax = 
                  1/HTAR; \[IndentingNewLine]As = 
                  1/HACT;\[IndentingNewLine]}];\[IndentingNewLine]] &;\)\)}], \
"Input"],

Cell[TextData[{
  "Try playing with ",
  StyleBox["RandomParameterSet", "Input"],
  " below to see how our nondimensionalization scheme makes life easier for \
us:  when nondimensionalized, there isn't any behavior we don't see comopared \
to the dimensionalized version, and the range stays between 0 and 1 for ",
  "TAR",
  " and ACT.  "
}], "Text"],

Cell[BoxData[{
    \(\(tend = 2000;\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          20, \(++i\), {\[IndentingNewLine]RandomParameterSet[
            1];  (*Try\ changing\ this\ from\ 1\ to\ \
2*) \[IndentingNewLine]PlotCycle[
            SolveCycle[]];\[IndentingNewLine]}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Storing parameter sets:", "Subsection"],

Cell["\<\
You should notice a few things:  First, this network tends to \
oscillate, and parameter sets that produce oscillations are pretty easy to \
find.  Second, if you want to go back and see what the parameter values are, \
you can't because they're not stored anywhere.  Let's fix this problem by \
making 3 functions:  one to return a compact list of all of the current \
parameter values, one to update all the paramter values when given a list \
containing them, and one to print them:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[ReadParamValues];\)\), "\[IndentingNewLine]", 
    \(\(ReadParamValues[] := {HACT, HACTp, As, kTa, nuTa, Pmax, kAt, nuAt, 
          Ts, Htar, HTAR, 
          Tmax};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Clear[WriteParamValues];\)\), "\[IndentingNewLine]", 
    \(\(WriteParamValues = 
        Module[{}, \[IndentingNewLine]\({HACT, HACTp, As, kTa, nuTa, Pmax, 
                  kAt, nuAt, Ts, Htar, HTAR, 
                  Tmax} = #1;\)\[IndentingNewLine]] \
&;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Clear[PrintParamValues];\)\), "\[IndentingNewLine]", 
    \(\(PrintParamValues = 
        Module[{HACT, HACTp, As, kTa, nuTa, Pmax, kAt, nuAt, Ts, Htar, HTAR, 
              Tmax}, \[IndentingNewLine]\[IndentingNewLine] (*We\ want\ this\ \
function\ NOT\ to\ change\ the\ parameter\ values\ \((just\ print\ them)\), 
              so\ we\ define\ new\ local\ copies\ of\ our\ \
\(\(parameters\)\(.\)\)*) \[IndentingNewLine]\[IndentingNewLine]{HACT, HACTp, 
                As, kTa, nuTa, Pmax, kAt, nuAt, Ts, Htar, HTAR, 
                Tmax} = #1; \[IndentingNewLine]\[IndentingNewLine] (*Now, \ 
              print\ a\ nicely - 
                formatted\ table\ of\ our\ values\ and\ a\ legend . \ \ See\ \
TableForm\ help\ for\ more\ \(\(info\)\(.\)\)*) \[IndentingNewLine]Print[
              TableForm[{{"\<HACT\>", "\<HACTp\>", "\<As\>", "\<kTa\>", \
"\<nuTa\>", "\<Pmax\>", "\<kAt\>", "\<nuAt\>", "\<Ts\>", "\<Htar\>", \
"\<HTAR\>", "\<Tmax\>"}, {HACT, HACTp, As, kTa, nuTa, Pmax, kAt, nuAt, Ts, 
                    Htar, HTAR, 
                    Tmax}}]];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell["\<\
Now, we can search for parameter sets that produce oscillations by \
running the code below:\
\>", "Text"],

Cell[BoxData[{
    \(\(tend = 2000;\)\), "\[IndentingNewLine]", 
    \(\(numsets = 20;\)\), "\[IndentingNewLine]", 
    \(\(psets\  = \ Table[{}, {numsets}];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          20, \(++i\), {\[IndentingNewLine]RandomParameterSet[
            2];  (*Try\ changing\ this\ from\ 1\ to\ \
2*) \[IndentingNewLine]PlotCycle[
            SolveCycle[]]; \[IndentingNewLine]Print["\<i=\>" <> 
              ToString[i]]; \[IndentingNewLine]psets[\([i]\)] = 
            ReadParamValues[];\[IndentingNewLine]}];\)\)}], "Input"],

Cell[TextData[{
  "When I ran the code above, I found that when ",
  StyleBox["i", "Input"],
  " = 14, I had a parameter set that gave good oscillations. Since you don't \
have my ",
  StyleBox["psets[[14]]", "Input"],
  " stored on your computer, I'll give you the parameter values in the \
command below to reproduce this oscillator:"
}], "Text"],

Cell[BoxData[{
    \(\(WriteParamValues[{92.68699293631526`, 13.8747112007261`, 
          0.010789000358303723`, 0.15711904084252795`, 5.389164171764785`, 
          0.45947664716187847`, 0.4804256714979159`, 7.485152265581335`, 
          0.039209044165847175`, 25.50431976281239`, 92.15984178301079`, 
          0.010850713072560254`}];\)\), "\[IndentingNewLine]", 
    \(\(PlotCycle[SolveCycle[]];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Automating searches:", "Section"],

Cell[CellGroupData[{

Cell["Scoring function:", "Subsection"],

Cell[TextData[{
  "Look at different parameter sets and their corresponding parameter values. \
 It would be nice if we could build up a library of, say, 100 or 1000 or \
10000 working parameter sets.  With this, we could see whether there were any \
correlations between sets or any disallowed values.  But, combing through \
tons of data and reassembling working sets by hand is tedius.  Is there a way \
we can automate our analysis?\n\nWe need something like a scoring function \
that takes the solution to our system, and returns whether it oscillates, the \
min and max values of each species during the oscillation, and the period of \
oscillation for ACT",
  StyleBox[" +", "Input"],
  "ACT",
  StyleBox["p", "Input"],
  " and ",
  "TAR",
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ScoreCycle];\)\), "\[IndentingNewLine]", 
    \(\(ScoreCycle = 
        Module[{}, \[IndentingNewLine]\(Return[{ScoreFunction[#1, 
                    ACT[t] + ACTp[t]], ScoreFunction[sol, TAR[t]]}, 
                Module];\)\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[TextData[{
  "The function above will be used by typing ",
  StyleBox["ScoreCycle[SolveCycle[]].", "Input"],
  "  It will try to evaluate whether ACT",
  StyleBox[" + ", "Input"],
  "ACT",
  StyleBox["p", "Input"],
  " and ",
  "TAR",
  " oscillate by using the ",
  StyleBox["ScoreFunction", "Input"],
  " below."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ScoreFunction];\)\), "\[IndentingNewLine]", 
    \(\(ScoreFunction = 
        Module[{sol, var, localmaximavalues, localmaximatimes, 
              localminimavalues, localminimatimes, i, oscillates, maxvalue, 
              minvalue, 
              period}, \[IndentingNewLine]sol\  = \ #1; \
\[IndentingNewLine]var\  = \ #2; \[IndentingNewLine]\[IndentingNewLine] \
(*Start\ by\ converting\ our\ solution\ to\ a\ time\ plot\ with\ the\ points\ \
exactly\ 1\ \(\(apart\)\(:\)\)*) \[IndentingNewLine]value\  = \ 
              Flatten[Table[
                  Evaluate[var /. sol], {t, 0, 
                    tend}]]; \[IndentingNewLine]\[IndentingNewLine] \
(*Strategy : \ \ find\ all\ the\ minima\ and\ maxima, \ \(\(starting\ from\ \
the\ end\ and\ going\ backwards\ to\ tend/
                    2\)\(:\)\)*) \[IndentingNewLine]localmaximavalues\  = \ \
{}; \[IndentingNewLine]localmaximatimes = {}; \
\[IndentingNewLine]localminimavalues\  = \ {}; \
\[IndentingNewLine]localminimatimes = {}; \[IndentingNewLine]For[
              i = tend - 1, 
              i > tend/
                  2, \(--i\), {\[IndentingNewLine]\[IndentingNewLine] (*Test\ \
for\ local\ maximum . \ \ If\ it\ is\ local\ max\ then\ record\ time\ and\ \
value*) \[IndentingNewLine]If[
                  value[\([i]\)] > value[\([i + 1]\)] && 
                    value[\([i]\)] > 
                      value[\([i - 1]\)], {\[IndentingNewLine]AppendTo[
                      localmaximavalues, 
                      value[\([i]\)]]; \[IndentingNewLine]AppendTo[
                      localmaximatimes, 
                      i];\[IndentingNewLine]}]; \[IndentingNewLine]\
\[IndentingNewLine] (*Test\ for\ local\ minimum . \ \ If\ it\ is\ local\ min\ \
then\ record\ time\ and\ value*) \[IndentingNewLine]If[
                  value[\([i]\)] < value[\([i + 1]\)] && 
                    value[\([i]\)] < 
                      value[\([i - 1]\)], {\[IndentingNewLine]AppendTo[
                      localminimavalues, 
                      value[\([i]\)]]; \[IndentingNewLine]AppendTo[
                      localminimatimes, 
                      i];\[IndentingNewLine]}];\[IndentingNewLine]}]; \
\[IndentingNewLine]\[IndentingNewLine] (*The\ variables\ below\ are\ going\ \
to\ be\ returned\ by\ our\ score\ function . \ \ For\ now, \ 
              we\ assume\ we\ didn' t\ get\ oscillations . \ \ We' 
                
                ll\ change\ these\ if\ there\ are\ oscillations\ detected\
*) \[IndentingNewLine]oscillates = False; \[IndentingNewLine]maxvalue = 
              0; \[IndentingNewLine]minvalue = 0; \[IndentingNewLine]period = 
              0; \[IndentingNewLine]\[IndentingNewLine] (*Assume\ we\ have\ \
oscillations\ if\ we\ have\ at\ least\ 2\ maxima\ and\ 2\ local\ minima\ in\ \
the\ last\ half\ of\ our\ run*) \[IndentingNewLine]If[
              Length[localmaximavalues] \[GreaterEqual] 2 && 
                Length[localminimavalues] \[GreaterEqual] 
                  2, \[IndentingNewLine]{\[IndentingNewLine] (*Also\ require\ \
that\ the\ maximum\ must\ be\ at\ least\ 1  %\ higher\ than\ the\ minimum\ \
and\ the\ period\ is\ longer\ than\ 4\ time\ units*) \[IndentingNewLine]\(If[
                    localmaximavalues[\([1]\)]/localminimavalues[\([1]\)] > 
                        1.01 && localmaximatimes[\([1]\)] - 
                          localmaximatimes[\([2]\)] > 
                        4, {\[IndentingNewLine]maxvalue = 
                        localmaximavalues[\([1]\)];  (*Last\ peak\ is\ the\ \
maximum*) \[IndentingNewLine]minvalue = 
                        localminimavalues[\([1]\)];  (*Last\ valley\ is\ the\ \
minimum*) \[IndentingNewLine]period = 
                        localmaximatimes[\([1]\)] - 
                          localmaximatimes[\([2]\)];  (*Period\ is\ the\ time\
\ between\ the\ last\ and\ second\ to\ last\ \
maxima*) \[IndentingNewLine]oscillates = 
                        True;\[IndentingNewLine]}];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]Return[{oscillates, maxvalue, minvalue, period}, 
              Module];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[TextData[{
  "Finally, let's write a function that takes the output of ",
  StyleBox["ScoreCycle", "Input"],
  " and prints a nicely formatted summary of the scores:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[PrintScore];\)\), "\[IndentingNewLine]", 
    \(\(PrintScore = 
        Module[{ACTscore, 
              TARscore}, \[IndentingNewLine]{ACTscore, 
                TARscore} = #1; \[IndentingNewLine]Print["\<ACT+ACTp:  \
oscillates=\>" <> ToString[ACTscore[\([1]\)]] <> "\<, peak value = \>" <> 
                ToString[ACTscore[\([2]\)]] <> "\<, valley value = \>" <> \ 
                ToString[ACTscore[\([3]\)]] <> "\<, period = \>" <> 
                ToString[
                  ACTscore[\([4]\)]]]; \[IndentingNewLine]Print["\<TAR:      \
oscillates=\>" <> ToString[TARscore[\([1]\)]] <> "\<, peak value = \>" <> 
                ToString[TARscore[\([2]\)]] <> "\<, valley value = \>" <> \ 
                ToString[TARscore[\([3]\)]] <> "\<, period = \>" <> 
                ToString[
                  TARscore[\([4]\)]]];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell["\<\
Our scoring function can make mistakes, and it's possible that it \
will have some false positives and false negatives.  But it does a reasonable \
job, so let's see how it works:\
\>", "Text"],

Cell[BoxData[{
    \(\(InitAffectors[];\)\), "\[IndentingNewLine]", 
    \(\(InitModel[];\)\), "\[IndentingNewLine]", 
    \(\(WriteParamValues[{92.68699293631526`, 13.8747112007261`, 
          0.010789000358303723`, 0.15711904084252795`, 5.389164171764785`, 
          0.45947664716187847`, 0.4804256714979159`, 7.485152265581335`, 
          0.039209044165847175`, 25.50431976281239`, 92.15984178301079`, 
          0.010850713072560254`}];\)\), "\[IndentingNewLine]", 
    \(\(sol = SolveCycle[];\)\), "\[IndentingNewLine]", 
    \(PlotCycle[sol]; PrintScore[ScoreCycle[sol]];\)}], "Input"],

Cell[TextData[{
  "Now, let's have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " search for parameter sets that produce oscillations.  The code below \
shows how to use a ",
  StyleBox["While", "Input"],
  " loop, which is a simplified version of a ",
  StyleBox["For", "Input"],
  " loop.  The ",
  StyleBox["While", "Input"],
  " loop has the format ",
  StyleBox["While[test, {body}].", "Input"],
  "  The test is evaluated, and if true, the body is run.  Then, the test is \
checked, and the body is run again until test fails.  The difference between \
",
  StyleBox["While", "Input"],
  " and ",
  StyleBox["For", "Input"],
  " is that ",
  StyleBox["While", "Input"],
  " is a stripped-down version that skips the initial values and increment \
(but these can be incorporated into the body).  \n\nThe function below will \
search through 50 randomly generated parameter sets, looking for those that \
oscillate.  If both ACT total and ",
  "TAR",
  " oscillate, it stores the parameter set in a list called ",
  StyleBox["workingparams", "Input"],
  " for later analysis.  Finally, it prints out a summary saying how many \
oscillating parameter sets it found and the fraction of sets that worked.  \
It's possible, by chance, that the code below will not find any working \
parameter sets.  If it doesn't the first time through, re-run the code and it \
should find working sets (about 10% of randomly generated parameter sets \
should oscillate, so if you search more than a hundred sets without luck, you \
might need to re-run the code above)."
}], "Text"],

Cell[BoxData[
    \(\(\( (*Reset\ the\ \
model*) \)\(\[IndentingNewLine]\)\(\(InitAffectors[];\)\[IndentingNewLine]
    \(InitModel[];\)\[IndentingNewLine]\[IndentingNewLine] (*Set\ the\ \
integration\ time\ to\ 1000*) \[IndentingNewLine]
    \(tend = 
        1000;\)\[IndentingNewLine]\[IndentingNewLine] (*The\ workingparams\ \
list\ will\ keep\ all\ of\ the\ parameter\ sets\ that\ produce\ oscillations \
. \ \ Currently\ empty*) \[IndentingNewLine]
    \(workingparams\  = \ {};\)\[IndentingNewLine]\[IndentingNewLine] (*Try\ \
generating\ 50\ random\ parameter\ sets\ and\ see\ if\ any\ of\ them\ \
oscillate*) \[IndentingNewLine]
    \(i = 1;\)\[IndentingNewLine]
    \(While[
        i \[LessEqual] 
          50, {\[IndentingNewLine]RandomParameterSet[
            2]; \[IndentingNewLine] (*The\ SolveCycle\ command\ is\ the\ \
slowest\ as\ it\ actually\ calls\ NDSolve\ and\ solves\ the\ system . \ \ We\ \
don' t\ want\ to\ call\ SolveCycle\ more\ than\ once\ for\ a\ parameter\ set, \
\ so\ we\ store\ its\ value\ in\ a\ variable*) \[IndentingNewLine]sol = 
            SolveCycle[]; \[IndentingNewLine]\[IndentingNewLine] (*Score\ the\
\ oscillator\ and\ see\ if\ it\ makes\ \
oscillations*) \[IndentingNewLine]score\  = \ 
            ScoreCycle[
              sol]; \[IndentingNewLine]\[IndentingNewLine] (*If\ there\ are\ \
oscillations\ in\ both\ ACT\  + \ 
              ACTp\ and\ TAR\ then\ plot\ it\ and\ add\ the\ parameter\ set\ \
to\ our\ list\ of\ working\ sets*) \[IndentingNewLine]If[
            score[\([1, 1]\)] \[Equal] True\  && \ 
              score[\([2, 1]\)] \[Equal] 
                True, {\[IndentingNewLine] (*\(PlotCycle[
                    sol];\)*) \[IndentingNewLine]\(AppendTo[workingparams, 
                  ReadParamValues[]];\)\[IndentingNewLine]}]; \
\[IndentingNewLine]\(++i\);\[IndentingNewLine]}];\)\[IndentingNewLine]\
\[IndentingNewLine] (*At\ the\ end, \ 
      print\ an\ informative\ message\ saying\ how\ many\ working\ sets\ we\ \
found*) \[IndentingNewLine]
    \(Print["\<Found \>" <> 
          ToString[
            Length[workingparams]] <> "\< working parameter sets out of \>" <> 
          ToString[i - 1] <> "\< tries giving a success rate of \>" <> 
          ToString[
            N[100  Length[
                    workingparams]/\((i - 
                      1)\)]] <> "\<%\>"];\)\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise:", "Subsection"],

Cell[TextData[{
  "Write a function called ",
  StyleBox["FindWorkingParamSets", "Input"],
  " that does the following:  You tell ",
  StyleBox["FindWorkingParamSets", "Input"],
  " how many working sets to find.  It then makes random parameter sets using \
",
  StyleBox["RandomParameterSet[2]", "Input"],
  " and finds working sets.  It saves both the working parameter sets AND \
their scores in separate lists.  Finally, it returns the working sets and \
their scores in a list in the form of {working parameter set list, \
corresponding score for each parameter set}.  The code in the example above \
is a start in this direction.  You may find other looping constructs useful \
such as the ",
  StyleBox["Do", "Input"],
  " and ",
  StyleBox["While", "Input"],
  " loops.  Read the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " help on these and see if you can figure out how to use them.  If you're \
stuck, ask for help from your instructors or classmates.\n\nHere's how to get \
started:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[FindWorkingParamSets];\)\), "\[IndentingNewLine]", 
    \(\(FindWorkingParamSets = 
        Module[\({}\)\(,\)\[IndentingNewLine] (*Your\ code\ here\
*) \[IndentingNewLine]\[IndentingNewLine]] &;\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saving & Loading data:", "Section"],

Cell[CellGroupData[{

Cell["Writing files:", "Subsection"],

Cell[TextData[{
  "After you've written your ",
  StyleBox["FindWorkingParamSets", "Input"],
  " function, use it to find 50 or 100 (or more) working parameter sets \
depending on your patience and computer speed.  This may take a significant \
amount of computer time.  If you do a large search, you'll often want to save \
your results to a file so you don't have re-find working parameter sets each \
time you start ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  \n\nSuppose after using your ",
  StyleBox["FindWorkingParamSets", "Input"],
  " function, you have a list of working parameter sets in the list called \
workingsets and their scores in the list called ",
  StyleBox["workingscores", "Input"],
  ".  To save these together, you'd type:"
}], "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\<full directory name\>"];\)\), "\[IndentingNewLine]", 
    \(\(Put[{workingsets, workingscores}, "\<filename\>"];\)\)}], "Input"],

Cell[TextData[{
  "Where you'd replace filename with name you want for your file, and put the \
full path name in the ",
  StyleBox["SetDirectory", "Input"],
  " command.  If you're running Windows, use the foreward slash / to separate \
directories rather than the backslash \\ you'd normally use.  \n\nTo save \
things to your desktop on a Mac, do the following:"
}], "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\</Users/kerrykim/Desktop\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Put[{workingsets, 
          workingscores}, "\<Myparams100206\>"];\)\)}], "Input"],

Cell["On windows, I'd do the following:", "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/Documents and Settings/kerrykim/Desktop\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Put[{workingsets, 
          workingscores}, "\<Myparams100206\>"];\)\)}], "Input"],

Cell[TextData[{
  "Be careful with your naming.  When you use ",
  StyleBox["Put", "Input"],
  ", it will ",
  StyleBox["automatically overwrite any file in that directory with the same \
name",
    FontSize->16,
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reading files:", "Subsection"],

Cell[TextData[{
  "To reload your data in some later ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, you can use the following command:"
}], "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\</Users/kerrykim/Desktop\>"];\)\), \
"\[IndentingNewLine]", 
    \(\({workingsets, workingscores} = << "\<Myparams100206\>";\)\)}], "Input"],

Cell[TextData[{
  StyleBox["SetDirectory", "Input"],
  " works as before, but the next line is different.  Here, we're going to \
set ",
  StyleBox["workingsets", "Input"],
  " and ",
  StyleBox["workingscores", "Input"],
  " equal to the contents of the file ",
  StyleBox["Myparams100206.", "Input"],
  "  The = indicates assignment, and the doubl eless than sign ",
  StyleBox["<<", "Input"],
  " means to ",
  StyleBox["Get", "Input"],
  " or Load the contents of the specified file.  So, the contents of ",
  StyleBox["Myparams100206", "Input"],
  " are fetched by the ",
  StyleBox["<< \"Myparams100206\"", "Input"],
  " command, and then assigned to the workginsets and workingscores \
variables."
}], "Text"]
}, Open  ]],

Cell["\<\
Exercise:  Save your working parameter sets and scores to a file.  

When you're done, go on to Lab 5B\
\>", "Subsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["GNU Free Documentation License\nTo view, Double click \
on the arrow to the right (2nd vertical blue line from the right edge, the \
one with the triangle at the bottom) --->",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Section"],

Cell[TextData[StyleBox["\t\tGNU Free Documentation License\n\t\t  Version \
1.2, November 2002\n\n\n Copyright (C) 2000,2001,2002  Free Software \
Foundation, Inc.\n     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  \
USA\n Everyone is permitted to copy and distribute verbatim copies\n of this \
license document, but changing it is not allowed.\n\n\n0. PREAMBLE\n\nThe \
purpose of this License is to make a manual, textbook, or other\nfunctional \
and useful document \"free\" in the sense of freedom: to\nassure everyone the \
effective freedom to copy and redistribute it,\nwith or without modifying it, \
either commercially or noncommercially.\nSecondarily, this License preserves \
for the author and publisher a way\nto get credit for their work, while not \
being considered responsible\nfor modifications made by others.\n\nThis \
License is a kind of \"copyleft\", which means that derivative\nworks of the \
document must themselves be free in the same sense.  It\ncomplements the GNU \
General Public License, which is a copyleft\nlicense designed for free \
software.\n\nWe have designed this License in order to use it for manuals for \
free\nsoftware, because free software needs free documentation: a free\n\
program should come with manuals providing the same freedoms that the\n\
software does.  But this License is not limited to software manuals;\nit can \
be used for any textual work, regardless of subject matter or\nwhether it is \
published as a printed book.  We recommend this License\nprincipally for \
works whose purpose is instruction or reference.\n\n\n1. APPLICABILITY AND \
DEFINITIONS\n\nThis License applies to any manual or other work, in any \
medium, that\ncontains a notice placed by the copyright holder saying it can \
be\ndistributed under the terms of this License.  Such a notice grants a\n\
world-wide, royalty-free license, unlimited in duration, to use that\nwork \
under the conditions stated herein.  The \"Document\", below,\nrefers to any \
such manual or work.  Any member of the public is a\nlicensee, and is \
addressed as \"you\".  You accept the license if you\ncopy, modify or \
distribute the work in a way requiring permission\nunder copyright law.\n\nA \
\"Modified Version\" of the Document means any work containing the\nDocument \
or a portion of it, either copied verbatim, or with\nmodifications and/or \
translated into another language.\n\nA \"Secondary Section\" is a named \
appendix or a front-matter section of\nthe Document that deals exclusively \
with the relationship of the\npublishers or authors of the Document to the \
Document's overall subject\n(or to related matters) and contains nothing that \
could fall directly\nwithin that overall subject.  (Thus, if the Document is \
in part a\ntextbook of mathematics, a Secondary Section may not explain any\n\
mathematics.)  The relationship could be a matter of historical\nconnection \
with the subject or with related matters, or of legal,\ncommercial, \
philosophical, ethical or political position regarding\nthem.\n\nThe \
\"Invariant Sections\" are certain Secondary Sections whose titles\nare \
designated, as being those of Invariant Sections, in the notice\nthat says \
that the Document is released under this License.  If a\nsection does not fit \
the above definition of Secondary then it is not\nallowed to be designated as \
Invariant.  The Document may contain zero\nInvariant Sections.  If the \
Document does not identify any Invariant\nSections then there are none.\n\n\
The \"Cover Texts\" are certain short passages of text that are listed,\nas \
Front-Cover Texts or Back-Cover Texts, in the notice that says that\nthe \
Document is released under this License.  A Front-Cover Text may\nbe at most \
5 words, and a Back-Cover Text may be at most 25 words.\n\nA \"Transparent\" \
copy of the Document means a machine-readable copy,\nrepresented in a format \
whose specification is available to the\ngeneral public, that is suitable for \
revising the document\nstraightforwardly with generic text editors or (for \
images composed of\npixels) generic paint programs or (for drawings) some \
widely available\ndrawing editor, and that is suitable for input to text \
formatters or\nfor automatic translation to a variety of formats suitable for \
input\nto text formatters.  A copy made in an otherwise Transparent file\n\
format whose markup, or absence of markup, has been arranged to thwart\nor \
discourage subsequent modification by readers is not Transparent.\nAn image \
format is not Transparent if used for any substantial amount\nof text.  A \
copy that is not \"Transparent\" is called \"Opaque\".\n\nExamples of \
suitable formats for Transparent copies include plain\nASCII without markup, \
Texinfo input format, LaTeX input format, SGML\nor XML using a publicly \
available DTD, and standard-conforming simple\nHTML, PostScript or PDF \
designed for human modification.  Examples of\ntransparent image formats \
include PNG, XCF and JPG.  Opaque formats\ninclude proprietary formats that \
can be read and edited only by\nproprietary word processors, SGML or XML for \
which the DTD and/or\nprocessing tools are not generally available, and the\n\
machine-generated HTML, PostScript or PDF produced by some word\nprocessors \
for output purposes only.\n\nThe \"Title Page\" means, for a printed book, \
the title page itself,\nplus such following pages as are needed to hold, \
legibly, the material\nthis License requires to appear in the title page.  \
For works in\nformats which do not have any title page as such, \"Title \
Page\" means\nthe text near the most prominent appearance of the work's \
title,\npreceding the beginning of the body of the text.\n\nA section \
\"Entitled XYZ\" means a named subunit of the Document whose\ntitle either is \
precisely XYZ or contains XYZ in parentheses following\ntext that translates \
XYZ in another language.  (Here XYZ stands for a\nspecific section name \
mentioned below, such as \"Acknowledgements\",\n\"Dedications\", \
\"Endorsements\", or \"History\".)  To \"Preserve the Title\"\nof such a \
section when you modify the Document means that it remains a\nsection \
\"Entitled XYZ\" according to this definition.\n\nThe Document may include \
Warranty Disclaimers next to the notice which\nstates that this License \
applies to the Document.  These Warranty\nDisclaimers are considered to be \
included by reference in this\nLicense, but only as regards disclaiming \
warranties: any other\nimplication that these Warranty Disclaimers may have \
is void and has\nno effect on the meaning of this License.\n\n\n2. VERBATIM \
COPYING\n\nYou may copy and distribute the Document in any medium, either\n\
commercially or noncommercially, provided that this License, the\ncopyright \
notices, and the license notice saying this License applies\nto the Document \
are reproduced in all copies, and that you add no other\nconditions \
whatsoever to those of this License.  You may not use\ntechnical measures to \
obstruct or control the reading or further\ncopying of the copies you make or \
distribute.  However, you may accept\ncompensation in exchange for copies.  \
If you distribute a large enough\nnumber of copies you must also follow the \
conditions in section 3.\n\nYou may also lend copies, under the same \
conditions stated above, and\nyou may publicly display copies.\n\n\n3. \
COPYING IN QUANTITY\n\nIf you publish printed copies (or copies in media that \
commonly have\nprinted covers) of the Document, numbering more than 100, and \
the\nDocument's license notice requires Cover Texts, you must enclose the\n\
copies in covers that carry, clearly and legibly, all these Cover\nTexts: \
Front-Cover Texts on the front cover, and Back-Cover Texts on\nthe back \
cover.  Both covers must also clearly and legibly identify\nyou as the \
publisher of these copies.  The front cover must present\nthe full title with \
all words of the title equally prominent and\nvisible.  You may add other \
material on the covers in addition.\nCopying with changes limited to the \
covers, as long as they preserve\nthe title of the Document and satisfy these \
conditions, can be treated\nas verbatim copying in other respects.\n\nIf the \
required texts for either cover are too voluminous to fit\nlegibly, you \
should put the first ones listed (as many as fit\nreasonably) on the actual \
cover, and continue the rest onto adjacent\npages.\n\nIf you publish or \
distribute Opaque copies of the Document numbering\nmore than 100, you must \
either include a machine-readable Transparent\ncopy along with each Opaque \
copy, or state in or with each Opaque copy\na computer-network location from \
which the general network-using\npublic has access to download using \
public-standard network protocols\na complete Transparent copy of the \
Document, free of added material.\nIf you use the latter option, you must \
take reasonably prudent steps,\nwhen you begin distribution of Opaque copies \
in quantity, to ensure\nthat this Transparent copy will remain thus \
accessible at the stated\nlocation until at least one year after the last \
time you distribute an\nOpaque copy (directly or through your agents or \
retailers) of that\nedition to the public.\n\nIt is requested, but not \
required, that you contact the authors of the\nDocument well before \
redistributing any large number of copies, to give\nthem a chance to provide \
you with an updated version of the Document.\n\n\n4. MODIFICATIONS\n\nYou may \
copy and distribute a Modified Version of the Document under\nthe conditions \
of sections 2 and 3 above, provided that you release\nthe Modified Version \
under precisely this License, with the Modified\nVersion filling the role of \
the Document, thus licensing distribution\nand modification of the Modified \
Version to whoever possesses a copy\nof it.  In addition, you must do these \
things in the Modified Version:\n\nA. Use in the Title Page (and on the \
covers, if any) a title distinct\n   from that of the Document, and from \
those of previous versions\n   (which should, if there were any, be listed in \
the History section\n   of the Document).  You may use the same title as a \
previous version\n   if the original publisher of that version gives \
permission.\nB. List on the Title Page, as authors, one or more persons or \
entities\n   responsible for authorship of the modifications in the Modified\n\
   Version, together with at least five of the principal authors of the\n   \
Document (all of its principal authors, if it has fewer than five),\n   \
unless they release you from this requirement.\nC. State on the Title page \
the name of the publisher of the\n   Modified Version, as the publisher.\nD. \
Preserve all the copyright notices of the Document.\nE. Add an appropriate \
copyright notice for your modifications\n   adjacent to the other copyright \
notices.\nF. Include, immediately after the copyright notices, a license \
notice\n   giving the public permission to use the Modified Version under the\
\n   terms of this License, in the form shown in the Addendum below.\nG. \
Preserve in that license notice the full lists of Invariant Sections\n   and \
required Cover Texts given in the Document's license notice.\nH. Include an \
unaltered copy of this License.\nI. Preserve the section Entitled \
\"History\", Preserve its Title, and add\n   to it an item stating at least \
the title, year, new authors, and\n   publisher of the Modified Version as \
given on the Title Page.  If\n   there is no section Entitled \"History\" in \
the Document, create one\n   stating the title, year, authors, and publisher \
of the Document as\n   given on its Title Page, then add an item describing \
the Modified\n   Version as stated in the previous sentence.\nJ. Preserve the \
network location, if any, given in the Document for\n   public access to a \
Transparent copy of the Document, and likewise\n   the network locations \
given in the Document for previous versions\n   it was based on.  These may \
be placed in the \"History\" section.\n   You may omit a network location for \
a work that was published at\n   least four years before the Document itself, \
or if the original\n   publisher of the version it refers to gives \
permission.\nK. For any section Entitled \"Acknowledgements\" or \
\"Dedications\",\n   Preserve the Title of the section, and preserve in the \
section all\n   the substance and tone of each of the contributor \
acknowledgements\n   and/or dedications given therein.\nL. Preserve all the \
Invariant Sections of the Document,\n   unaltered in their text and in their \
titles.  Section numbers\n   or the equivalent are not considered part of the \
section titles.\nM. Delete any section Entitled \"Endorsements\".  Such a \
section\n   may not be included in the Modified Version.\nN. Do not retitle \
any existing section to be Entitled \"Endorsements\"\n   or to conflict in \
title with any Invariant Section.\nO. Preserve any Warranty Disclaimers.\n\n\
If the Modified Version includes new front-matter sections or\nappendices \
that qualify as Secondary Sections and contain no material\ncopied from the \
Document, you may at your option designate some or all\nof these sections as \
invariant.  To do this, add their titles to the\nlist of Invariant Sections \
in the Modified Version's license notice.\nThese titles must be distinct from \
any other section titles.\n\nYou may add a section Entitled \"Endorsements\", \
provided it contains\nnothing but endorsements of your Modified Version by \
various\nparties--for example, statements of peer review or that the text has\
\nbeen approved by an organization as the authoritative definition of a\n\
standard.\n\nYou may add a passage of up to five words as a Front-Cover Text, \
and a\npassage of up to 25 words as a Back-Cover Text, to the end of the list\
\nof Cover Texts in the Modified Version.  Only one passage of\nFront-Cover \
Text and one of Back-Cover Text may be added by (or\nthrough arrangements \
made by) any one entity.  If the Document already\nincludes a cover text for \
the same cover, previously added by you or\nby arrangement made by the same \
entity you are acting on behalf of,\nyou may not add another; but you may \
replace the old one, on explicit\npermission from the previous publisher that \
added the old one.\n\nThe author(s) and publisher(s) of the Document do not \
by this License\ngive permission to use their names for publicity for or to \
assert or\nimply endorsement of any Modified Version.\n\n\n5. COMBINING \
DOCUMENTS\n\nYou may combine the Document with other documents released under \
this\nLicense, under the terms defined in section 4 above for modified\n\
versions, provided that you include in the combination all of the\nInvariant \
Sections of all of the original documents, unmodified, and\nlist them all as \
Invariant Sections of your combined work in its\nlicense notice, and that you \
preserve all their Warranty Disclaimers.\n\nThe combined work need only \
contain one copy of this License, and\nmultiple identical Invariant Sections \
may be replaced with a single\ncopy.  If there are multiple Invariant \
Sections with the same name but\ndifferent contents, make the title of each \
such section unique by\nadding at the end of it, in parentheses, the name of \
the original\nauthor or publisher of that section if known, or else a unique \
number.\nMake the same adjustment to the section titles in the list of\n\
Invariant Sections in the license notice of the combined work.\n\nIn the \
combination, you must combine any sections Entitled \"History\"\nin the \
various original documents, forming one section Entitled\n\"History\"; \
likewise combine any sections Entitled \"Acknowledgements\",\nand any \
sections Entitled \"Dedications\".  You must delete all sections\nEntitled \
\"Endorsements\".\n\n\n6. COLLECTIONS OF DOCUMENTS\n\nYou may make a \
collection consisting of the Document and other documents\nreleased under \
this License, and replace the individual copies of this\nLicense in the \
various documents with a single copy that is included in\nthe collection, \
provided that you follow the rules of this License for\nverbatim copying of \
each of the documents in all other respects.\n\nYou may extract a single \
document from such a collection, and distribute\nit individually under this \
License, provided you insert a copy of this\nLicense into the extracted \
document, and follow this License in all\nother respects regarding verbatim \
copying of that document.\n\n\n7. AGGREGATION WITH INDEPENDENT WORKS\n\nA \
compilation of the Document or its derivatives with other separate\nand \
independent documents or works, in or on a volume of a storage or\n\
distribution medium, is called an \"aggregate\" if the copyright\nresulting \
from the compilation is not used to limit the legal rights\nof the \
compilation's users beyond what the individual works permit.\nWhen the \
Document is included in an aggregate, this License does not\napply to the \
other works in the aggregate which are not themselves\nderivative works of \
the Document.\n\nIf the Cover Text requirement of section 3 is applicable to \
these\ncopies of the Document, then if the Document is less than one half of\n\
the entire aggregate, the Document's Cover Texts may be placed on\ncovers \
that bracket the Document within the aggregate, or the\nelectronic equivalent \
of covers if the Document is in electronic form.\nOtherwise they must appear \
on printed covers that bracket the whole\naggregate.\n\n\n8. TRANSLATION\n\n\
Translation is considered a kind of modification, so you may\ndistribute \
translations of the Document under the terms of section 4.\nReplacing \
Invariant Sections with translations requires special\npermission from their \
copyright holders, but you may include\ntranslations of some or all Invariant \
Sections in addition to the\noriginal versions of these Invariant Sections.  \
You may include a\ntranslation of this License, and all the license notices \
in the\nDocument, and any Warranty Disclaimers, provided that you also \
include\nthe original English version of this License and the original \
versions\nof those notices and disclaimers.  In case of a disagreement \
between\nthe translation and the original version of this License or a notice\
\nor disclaimer, the original version will prevail.\n\nIf a section in the \
Document is Entitled \"Acknowledgements\",\n\"Dedications\", or \"History\", \
the requirement (section 4) to Preserve\nits Title (section 1) will typically \
require changing the actual\ntitle.\n\n\n9. TERMINATION\n\nYou may not copy, \
modify, sublicense, or distribute the Document except\nas expressly provided \
for under this License.  Any other attempt to\ncopy, modify, sublicense or \
distribute the Document is void, and will\nautomatically terminate your \
rights under this License.  However,\nparties who have received copies, or \
rights, from you under this\nLicense will not have their licenses terminated \
so long as such\nparties remain in full compliance.\n\n\n10. FUTURE REVISIONS \
OF THIS LICENSE\n\nThe Free Software Foundation may publish new, revised \
versions\nof the GNU Free Documentation License from time to time.  Such new\n\
versions will be similar in spirit to the present version, but may\ndiffer in \
detail to address new problems or concerns.  See\n\
http://www.gnu.org/copyleft/.\n\nEach version of the License is given a \
distinguishing version number.\nIf the Document specifies that a particular \
numbered version of this\nLicense \"or any later version\" applies to it, you \
have the option of\nfollowing the terms and conditions either of that \
specified version or\nof any later version that has been published (not as a \
draft) by the\nFree Software Foundation.  If the Document does not specify a \
version\nnumber of this License, you may choose any version ever published \
(not\nas a draft) by the Free Software Foundation.\n\n\nADDENDUM: How to use \
this License for your documents\n\nTo use this License in a document you have \
written, include a copy of\nthe License in the document and put the following \
copyright and\nlicense notices just after the title page:\n\n    Copyright \
(c)  YEAR  YOUR NAME.\n    Permission is granted to copy, distribute and/or \
modify this document\n    under the terms of the GNU Free Documentation \
License, Version 1.2\n    or any later version published by the Free Software \
Foundation;\n    with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.\n    A copy of the license is included in the section \
entitled \"GNU\n    Free Documentation License\".\n\nIf you have Invariant \
Sections, Front-Cover Texts and Back-Cover Texts,\nreplace the \
\"with...Texts.\" line with this:\n\n    with the Invariant Sections being \
LIST THEIR TITLES, with the\n    Front-Cover Texts being LIST, and with the \
Back-Cover Texts being LIST.\n\nIf you have Invariant Sections without Cover \
Texts, or some other\ncombination of the three, merge those two alternatives \
to suit the\nsituation.\n\nIf your document contains nontrivial examples of \
program code, we\nrecommend releasing these examples in parallel under your \
choice of\nfree software license, such as the GNU General Public License,\nto \
permit their use in free software.\n",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1625}, {0, 1028}},
Evaluator->"Local",
WindowSize->{1103, 810},
WindowMargins->{{Automatic, 113}, {Automatic, 82}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 49, 0, 88, "Title"],
Cell[1828, 55, 570, 8, 94, "Text"],

Cell[CellGroupData[{
Cell[2423, 67, 28, 0, 69, "Section"],
Cell[2454, 69, 900, 16, 96, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3391, 90, 109, 5, 69, "Section"],

Cell[CellGroupData[{
Cell[3525, 99, 131, 5, 38, "Subsection"],
Cell[3659, 106, 106, 3, 30, "Text"],
Cell[3768, 111, 285, 5, 107, "Input"],
Cell[4056, 118, 42, 1, 27, "Input"],
Cell[4101, 121, 2096, 59, 199, "Text"],
Cell[6200, 182, 276, 5, 107, "Input"],
Cell[6479, 189, 50, 1, 27, "Input"],
Cell[6532, 192, 323, 9, 31, "Text"],
Cell[6858, 203, 99, 3, 30, "Text"],
Cell[6960, 208, 67, 1, 27, "Input"],
Cell[7030, 211, 51, 1, 27, "Input"],
Cell[7084, 214, 256, 5, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7377, 224, 53, 0, 38, "Subsection"],
Cell[7433, 226, 493, 9, 63, "Text"],
Cell[7929, 237, 191, 3, 59, "Input"],
Cell[8123, 242, 52, 1, 27, "Input"],
Cell[8178, 245, 52, 1, 27, "Input"],
Cell[8233, 248, 483, 11, 48, "Text"],
Cell[8719, 261, 178, 3, 59, "Input"],
Cell[8900, 266, 62, 1, 27, "Input"],
Cell[8965, 269, 760, 19, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9762, 293, 75, 0, 38, "Subsection"],
Cell[9840, 295, 176, 5, 31, "Text"],
Cell[10019, 302, 585, 11, 187, "Input"],
Cell[10607, 315, 43, 1, 27, "Input"],
Cell[10653, 318, 953, 15, 128, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11643, 338, 38, 0, 38, "Subsection"],
Cell[11684, 340, 1656, 24, 390, "Text"],
Cell[13343, 366, 2992, 93, 115, "Input"],
Cell[16338, 461, 1982, 40, 282, "Text"],
Cell[18323, 503, 178, 6, 32, "Text"],
Cell[18504, 511, 1348, 36, 155, "Input"],
Cell[19855, 549, 99, 3, 30, "Text"],
Cell[19957, 554, 439, 8, 171, "Input"],
Cell[20399, 564, 219, 4, 30, "Text"],
Cell[20621, 570, 43, 1, 27, "Input"],
Cell[20667, 573, 166, 6, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20870, 584, 42, 0, 38, "Subsection"],
Cell[20915, 586, 233, 6, 32, "Text"],
Cell[21151, 594, 166, 4, 59, "Input"],
Cell[21320, 600, 539, 12, 48, "Text"],
Cell[21862, 614, 145, 3, 30, "Text"],
Cell[22010, 619, 265, 5, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22312, 629, 39, 0, 38, "Subsection"],
Cell[22354, 631, 386, 7, 47, "Text"],
Cell[22743, 640, 129, 3, 30, "Text"],
Cell[22875, 645, 759, 14, 267, "Input"],
Cell[23637, 661, 331, 8, 47, "Text"],
Cell[23971, 671, 62, 1, 27, "Input"],
Cell[24036, 674, 957, 25, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25030, 704, 38, 0, 38, "Subsection"],
Cell[25071, 706, 788, 22, 81, "Text"],
Cell[25862, 730, 591, 11, 187, "Input"],
Cell[26456, 743, 143, 6, 31, "Text"],
Cell[26602, 751, 309, 5, 91, "Input"],
Cell[26914, 758, 347, 5, 91, "Input"],
Cell[27264, 765, 263, 6, 31, "Text"],
Cell[27530, 773, 760, 14, 267, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28327, 792, 78, 0, 38, "Subsection"],
Cell[28408, 794, 224, 4, 30, "Text"],
Cell[28635, 800, 860, 14, 267, "Input"],
Cell[29498, 816, 165, 5, 32, "Text"],
Cell[29666, 823, 59, 1, 27, "Input"],
Cell[29728, 826, 326, 7, 48, "Text"],
Cell[30057, 835, 61, 1, 27, "Input"],
Cell[30121, 838, 178, 3, 43, "Input"],
Cell[30302, 843, 180, 6, 32, "Text"],
Cell[30485, 851, 141, 3, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30663, 859, 63, 0, 38, "Subsection"],
Cell[30729, 861, 907, 14, 111, "Text"],
Cell[31639, 877, 720, 12, 187, "Input"],
Cell[32362, 891, 127, 2, 43, "Input"],
Cell[32492, 895, 127, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32656, 902, 31, 0, 38, "Subsection"],
Cell[32690, 904, 1931, 38, 195, "Text"],

Cell[CellGroupData[{
Cell[34646, 946, 61, 1, 27, "Input"],
Cell[34710, 949, 90, 1, 23, "Print"],
Cell[34803, 952, 90, 1, 23, "Print"],
Cell[34896, 955, 90, 1, 23, "Print"],
Cell[34989, 958, 90, 1, 23, "Print"],
Cell[35082, 961, 90, 1, 23, "Print"],
Cell[35175, 964, 90, 1, 23, "Print"],
Cell[35268, 967, 93, 1, 23, "Print"],
Cell[35364, 970, 93, 1, 23, "Print"],
Cell[35460, 973, 93, 1, 23, "Print"],
Cell[35556, 976, 93, 1, 23, "Print"],
Cell[35652, 979, 93, 1, 23, "Print"],
Cell[35748, 982, 93, 1, 23, "Print"],
Cell[35844, 985, 93, 1, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35998, 993, 52, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[36075, 997, 59, 0, 38, "Subsection"],
Cell[36137, 999, 593, 10, 63, "Text"],
Cell[36733, 1011, 2906, 48, 619, "Input"],
Cell[39642, 1061, 713, 14, 97, "Text"],
Cell[40358, 1077, 1123, 18, 203, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41518, 1100, 41, 0, 38, "Subsection"],
Cell[41562, 1102, 195, 4, 31, "Text"],
Cell[41760, 1108, 214, 4, 43, "Input"],
Cell[41977, 1114, 460, 9, 91, "Input"],
Cell[42440, 1125, 386, 7, 91, "Input"],
Cell[42829, 1134, 556, 12, 96, "Text"],
Cell[43388, 1148, 167, 3, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43592, 1156, 55, 0, 38, "Subsection"],
Cell[43650, 1158, 72, 0, 30, "Text"],
Cell[43725, 1160, 409, 7, 123, "Input"],
Cell[44137, 1169, 503, 9, 79, "Text"],
Cell[44643, 1180, 516, 10, 155, "Input"],
Cell[45162, 1192, 93, 3, 30, "Text"],
Cell[45258, 1197, 548, 11, 171, "Input"],
Cell[45809, 1210, 285, 5, 46, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46143, 1221, 45, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[46213, 1225, 50, 0, 38, "Subsection"],
Cell[46266, 1227, 365, 6, 46, "Text"],
Cell[46634, 1235, 148, 2, 43, "Input"],
Cell[46785, 1239, 96, 3, 30, "Text"],
Cell[46884, 1244, 117, 2, 27, "Input"],
Cell[47004, 1248, 220, 4, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47261, 1257, 114, 5, 38, "Subsection"],
Cell[47378, 1264, 192, 5, 31, "Text"],
Cell[47573, 1271, 258, 6, 75, "Input"],
Cell[47834, 1279, 230, 3, 43, "Input"],
Cell[48067, 1284, 125, 3, 43, "Input"],
Cell[48195, 1289, 159, 2, 43, "Input"],
Cell[48357, 1293, 68, 0, 30, "Text"],
Cell[48428, 1295, 38, 1, 27, "Input"],
Cell[48469, 1298, 172, 5, 31, "Text"],
Cell[48644, 1305, 47, 1, 27, "Input"],
Cell[48694, 1308, 46, 0, 30, "Text"],
Cell[48743, 1310, 88, 1, 27, "Input"],
Cell[48834, 1313, 114, 4, 31, "Text"],
Cell[48951, 1319, 53, 1, 27, "Input"],
Cell[49007, 1322, 126, 4, 31, "Text"],
Cell[49136, 1328, 56, 1, 27, "Input"],
Cell[49195, 1331, 188, 4, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49420, 1340, 54, 0, 38, "Subsection"],
Cell[49477, 1342, 154, 3, 30, "Text"],
Cell[49634, 1347, 228, 5, 91, "Input"],
Cell[49865, 1354, 91, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49993, 1362, 45, 0, 38, "Subsection"],
Cell[50041, 1364, 409, 7, 46, "Text"],
Cell[50453, 1373, 3247, 55, 779, "Input"],
Cell[53703, 1430, 351, 8, 47, "Text"],
Cell[54057, 1440, 325, 7, 91, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54419, 1452, 45, 0, 38, "Subsection"],
Cell[54467, 1454, 509, 8, 62, "Text"],
Cell[54979, 1464, 1677, 27, 331, "Input"],
Cell[56659, 1493, 116, 3, 30, "Text"],
Cell[56778, 1498, 581, 11, 155, "Input"],
Cell[57362, 1511, 348, 8, 47, "Text"],
Cell[57713, 1521, 417, 6, 75, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58179, 1533, 39, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[58243, 1537, 39, 0, 38, "Subsection"],
Cell[58285, 1539, 766, 16, 95, "Text"],
Cell[59054, 1557, 294, 5, 75, "Input"],
Cell[59351, 1564, 331, 12, 31, "Text"],
Cell[59685, 1578, 4146, 69, 859, "Input"],
Cell[63834, 1649, 183, 4, 31, "Text"],
Cell[64020, 1655, 899, 15, 139, "Input"],
Cell[64922, 1672, 203, 4, 30, "Text"],
Cell[65128, 1678, 594, 9, 139, "Input"],
Cell[65725, 1689, 1580, 35, 147, "Text"],
Cell[67308, 1726, 2374, 44, 539, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69719, 1775, 31, 0, 38, "Subsection"],
Cell[69753, 1777, 1022, 23, 115, "Text"],
Cell[70778, 1802, 240, 4, 91, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71067, 1812, 41, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[71133, 1816, 36, 0, 38, "Subsection"],
Cell[71172, 1818, 777, 16, 98, "Text"],
Cell[71952, 1836, 167, 2, 43, "Input"],
Cell[72122, 1840, 377, 7, 79, "Text"],
Cell[72502, 1849, 190, 4, 43, "Input"],
Cell[72695, 1855, 49, 0, 30, "Text"],
Cell[72747, 1857, 209, 4, 43, "Input"],
Cell[72959, 1863, 297, 10, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73293, 1878, 36, 0, 38, "Subsection"],
Cell[73332, 1880, 168, 5, 32, "Text"],
Cell[73503, 1887, 178, 3, 43, "Input"],
Cell[73684, 1892, 716, 19, 64, "Text"]
}, Open  ]],
Cell[74415, 1914, 132, 4, 74, "Subsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74584, 1923, 260, 4, 83, "Section"],
Cell[74847, 1929, 21527, 282, 7974, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

