(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36036,        655]*)
(*NotebookOutlinePosition[     36675,        677]*)
(*  CellTagsIndexPosition[     36631,        673]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Lab 5B:  Visualizing and exploring parameter space", "Title"],

Cell[TextData[StyleBox["Copyright (c)  2006, 2008 Kerry Kim\nPermission is \
granted to copy, distribute and/or modify this document under the terms of \
the GNU Free Documentation License, Version 1.2 or any later version \
published by the Free Software Foundation; with no Invariant Sections, no \
Front-Cover Texts, and no Back-Cover Texts.  A copy of the license is \
included in the section entitled \"GNU Free Documentation License\"",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"],

Cell[CellGroupData[{

Cell["Overview:", "Section"],

Cell[TextData[{
  "In Lab 5A, you started to build up a \"library\" of useful functions for \
exploring the behavior of the oscillator.  In this lab, we'll continue to add \
to our list of useful things to do in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and explore different ways of trying to understand how parameter values \
influence the model."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reloading libraries of commands:", "Section"],

Cell[TextData[{
  "By now, you're probably tired of shift-enter through a bunch of \
definitions when you start up ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " again.  We're going to be using all of the functions we wrote in lab 5A, \
and add to them.  Rather than have to load lab 5A, we can have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " load into memory a file that contains all of our useful function \
definitions and run them all at once"
}], "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\<directory where this tutorial on your hard drive\>"];\
\)\), "\[IndentingNewLine]", 
    \(\(<< "\<CycleFunctions.m\>";\)\)}], "Input"],

Cell["\<\
You should get a message saying that CycleFuncitons.m was loaded.  \
If so, run the following:\
\>", "Text"],

Cell[BoxData[{
    \(\(InitAffectors[];\)\), "\[IndentingNewLine]", 
    \(\(InitModel[];\)\), "\[IndentingNewLine]", 
    \(\(PlotCycle[SolveCycle[]];\)\)}], "Input"],

Cell[TextData[{
  "As you can see, we've automatically loaded in our old functions without \
having to shift-enter them manually.  Now, open the CycleFunctions.nb file in \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and a new notebook will appear.  This notebook contains the old function \
definitions in a slightly different format, and also contains comments on how \
the file was genrated and how it can be used.  Read those comments, and \
follow the exercise of adding your ",
  StyleBox["FindWorkingParamSets", "Input"],
  " from lab 5.\n\nWhen you're done with that, verify that your changes \
worked by running the code below:"
}], "Text"],

Cell[BoxData[{\(SetDirectory["\</Users/kerrykim/Documents/5 Parameter \
Searches\>"];\), "\[IndentingNewLine]", 
    RowBox[{\(<< "\<CycleFunctions.m\>";\), "\[IndentingNewLine]", 
      "\[IndentingNewLine]", \( (*We\ need\ to\ reload\ CycleFunctions . 
            m\ because\ you' ve\ updated\ your\ CycleFunctions\ notebook*) \),
       "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(InitModel[];\), "\
\[IndentingNewLine]", \(InitAffectors[];\), "\[IndentingNewLine]", 
    StyleBox[\(FindWorkingParamSets[2]\),
      "Input"]}], "Input"],

Cell[TextData[{
  "You should verify that ",
  StyleBox["FindWorkingParamSets", "Input"],
  " worked like it did in lab 5.\n\nAs you proceed through this lab, you \
should add useful functions to your CycleFunctions notebook, save it, and \
reloda CycleFunctions.m periodically.  After this lab, you'll have a large \
library of functions that let you do useful things to explore how the \
oscillator works."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Alternate ways of visualization & analysis of the oscillator:\
\>", \
"Section"],

Cell[BoxData[{\(InitModel[];\), "\[IndentingNewLine]", \(InitAffectors[];\), \
"\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\({params, scores}\), "=", 
        StyleBox[\(FindWorkingParamSets[50]\),
          "Input"]}], 
      StyleBox[";",
        "Input"]}]}], "Input"],

Cell[CellGroupData[{

Cell["Visualizing scores with parameter values:", "Subsection"],

Cell["\<\
In Lab 5, you saw code that let you sweep across a parameter value \
whlie watching the phase or time plots.  Now, you can sweep across parameter \
values and visualize in a different way how the period and amplitude \
change:\
\>", "Text"],

Cell[BoxData[{
    \(\(InitModel[];\)\), "\[IndentingNewLine]", 
    \(\(InitAffectors[];\)\), "\[IndentingNewLine]", 
    \(\(period\  = \ {};\)\), "\[IndentingNewLine]", 
    \(\(ACTamplitude = {};\)\), "\[IndentingNewLine]", 
    \(\(TARamplitude = {};\)\), "\[IndentingNewLine]", 
    \(\(For[kAt = 0.05, kAt < 1.1, 
        kAt += 0.05, \[IndentingNewLine]{\[IndentingNewLine]sol = 
            SolveCycle[]; \[IndentingNewLine]scor = 
            ScoreCycle[sol]; \[IndentingNewLine]AppendTo[
            period, {kAt, scor[\([1, 4]\)]}]; \[IndentingNewLine]AppendTo[
            ACTamplitude, {kAt, 
              scor[\([1, 2]\)] - 
                scor[\([1, 3]\)]}]; \[IndentingNewLine]AppendTo[
            TARamplitude, {kAt, 
              scor[\([2, 2]\)] - 
                scor[\([2, 
                    3]\)]}];\[IndentingNewLine]}];\)\), \
"\[IndentingNewLine]", 
    \(\(ListPlot[period, 
        PlotLabel -> "\<Period vs kAt\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[ACTamplitude, 
        PlotLabel -> "\<ACT amplitude vs kAt\>"];\)\), "\[IndentingNewLine]", \

    \(\(ListPlot[TARamplitude, 
        PlotLabel -> "\<TAR amplitude vs kAt\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualizing working parameter sets:", "Subsection"],

Cell["\<\
In Lab 5, you saved several working parameter sets.  Wouldn't it be \
nice to see whether there were any 'excluded' values or tendancies?  \
Something like whether kAt always had to be always high?  Or maybe HACT had \
to always be low?  Shown below is a function that takes a parameter set, and \
renormalizes all the values so that a parameter is 0 if it is at the minimum \
generated by our random parameter generator and 1 if it's the maximum \
value:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[NormalizeSet];\)\), "\[IndentingNewLine]", 
    \(\(NormalizeSet = 
        Module[{}, \[IndentingNewLine]\[IndentingNewLine] (*This\ function\ \
assumes\ that\ we\ used\ the\ nondimensionalized\ parameter\ groupings\ and\ \
we\ haven' 
                t\ changed\ the\ range\ of\ the\ bounds\ on\ the\ parameters\ \
in\ RandomParameterSet . \ \ Don' 
                t\ worry\ about\ following\ all\ of\ the\ algebra\ in\ \
getting\ the\ scaling\ factors\ right*) \[IndentingNewLine] (*These\ are\ \
copied\ straight\ out\ of\ RandomParameterSet*) \[IndentingNewLine]Hmin\  = \ 
              10; \[IndentingNewLine]Hmax\  = \ 
              120; \[IndentingNewLine]kmin\  = \ 
              0.025; \[IndentingNewLine]kmax\  = \ 
              1.2; \[IndentingNewLine]numin\  = \ 
              1; \[IndentingNewLine]numax\  = \ 
              8; \[IndentingNewLine]\[IndentingNewLine]WriteParamValues[#1]; \
\[IndentingNewLine] (*Scale\ all\ the\ parameter\ values\ so\ that\ they\ \
range\ from\ 0\ if\ they' 
                re\ at\ the\ minimum\ allowed\ by\ the\ random\ generator\ \
and\ 1\ if\ they' 
                re\ at\ the\ maximum*) \[IndentingNewLine]HACTp = \((HACTp - 
                    0.1  HACT)\)/\((0.1  
                    HACT)\); \  (*This\ one\ is\ tricky\ to\ get\ \(\(right\)\
\(.\)\)\ *) \[IndentingNewLine]\[IndentingNewLine] (*The\ rest\ follow\ this\ \
general\ formula*) \[IndentingNewLine]HACT = \((HACT - Hmin)\)/\((Hmax - 
                    Hmin)\); \ \[IndentingNewLine]Htar = \((Htar - 
                    Hmin)\)/\((Hmax - 
                    Hmin)\); \[IndentingNewLine]HTAR = \((HTAR - 
                    Hmin)\)/\((Hmax - 
                    Hmin)\); \[IndentingNewLine]Pmax = \((Pmax - 
                    kmin)\)/\((kmax - 
                    kmin)\); \[IndentingNewLine]kTa = \((kTa - 
                    kmin)\)/\((kmax - 
                    kmin)\); \[IndentingNewLine]kAt = \((kAt - 
                    kmin)\)/\((kmax - 
                    kmin)\); \[IndentingNewLine]nuTa = \((nuTa - 
                    numin)\)/\((numax - 
                    numin)\); \[IndentingNewLine]nuAt = \((nuAt - 
                    numin)\)/\((numax - 
                    numin)\); \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine] (*These\ are\ nondimensionalized\ and\ varied\ inversely\ \
with\ other\ parameters*) \[IndentingNewLine]Ts = 
              1 - Htar; \ \[IndentingNewLine]Tmax = 
              1 - HTAR; \[IndentingNewLine]As = 
              1 - HACT; \[IndentingNewLine]\[IndentingNewLine]Return[
              ReadParamValues[], 
              Module];\[IndentingNewLine]] &;\)\)}], "Input"],

Cell[TextData[{
  "Verify for yourself that the above function works as advertised by using \
it on your saved parameter sets.  Load them into this ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session using the commands below:"
}], "Text"],

Cell[BoxData[{
    \(\(SetDirectory["\<Path to your directory\>"];\)\), \
"\[IndentingNewLine]", 
    \(\({workingsets, 
          workingscores} = << "\<Your file containing saved data\>";\)\)}], \
"Input"],

Cell["Now, let's visualize our normalized parameter values:", "Text"],

Cell[BoxData[{
    \(\(ticks = 
        Transpose[{Range[
              12], {"\<HACT\>", "\<HACTp\>", "\<As\>", "\<kTa\>", "\<nuTa\>", \
"\<Pmax\>", "\<kAt\>", "\<nuAt\>", "\<Ts\>", "\<Htar\>", "\<HTAR\>", \
"\<Tmax\>"}}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[NormalizeSet[workingsets[\([1]\)]], 
        Ticks \[Rule] {ticks, Automatic}, ImageSize \[Rule] 600, 
        PlotJoined \[Rule] True];\)\)}], "Input"],

Cell["\<\
And you can visualize all the parameter sets using the code \
below:\
\>", "Text"],

Cell[BoxData[{
    \(\(ticks = 
        Transpose[{Range[
              12], {"\<HACT\>", "\<HACTp\>", "\<As\>", "\<kTa\>", "\<nuTa\>", \
"\<Pmax\>", "\<kAt\>", "\<nuAt\>", "\<Ts\>", "\<Htar\>", "\<HTAR\>", \
"\<Tmax\>"}}];\)\), "\[IndentingNewLine]", 
    \(\(plots = 
        Table[{}, {Length[workingsets]}];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[workingsets], \(++i\), {\[IndentingNewLine]\(plots[\([i]\)] \
= ListPlot[NormalizeSet[workingsets[\([i]\)]], 
                Ticks \[Rule] {ticks, Automatic}, ImageSize \[Rule] 600, 
                PlotJoined \[Rule] True, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {Hue[
                      i/Length[
                          workingsets]]}];\)\[IndentingNewLine]}];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[plots, DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[TextData[{
  "Besides the correlation between As",
  StyleBox["/H", "Input"],
  "ACT",
  StyleBox[", ", "Input"],
  "Ts",
  StyleBox["/H", "Input"],
  "tar, and Tmax",
  StyleBox["/H", "Input"],
  "TAR which are consequences of our nondimensionalization, do you see any \
general patterns emerge?  Constraints on parameter values (i.e certain \
parameters are almost always above/below certain levels)?  Recall also that \
we used some general-purpose activation curves to describe transcriptional \
activation and phosphorylation.  Based on what you see, was this justified or \
are there any severe problems?  "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises:", "Section"],

Cell[TextData[{
  "This lab covered an enormous amount of ground.  Hopefully, you learned a \
lot and have more tools to explore your models.  Things to try:\n\nUse the \
tools & techniques you developed here to investigate other networks:  the \
coupled springs from lab 3 and the Turing networks from lab 4.  Or \
investigate the oscillator more.\n\nTry looking for correlations between \
working parameters.  Make a ",
  StyleBox["ListPlot", "Input"],
  " of different pairs of parameter values for working parameter sets.  For \
example, try plotting ",
  StyleBox["{", "Input"],
  "nuAt",
  StyleBox[", ", "Input"],
  "nuTa",
  StyleBox["}", "Input"],
  " pairs for all working parameter sets using ",
  StyleBox["ListPlot", "Input"],
  " to see whether there's any correlation between the two."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["GNU Free Documentation License\nTo view, Double click \
on the arrow to the right (2nd vertical blue line from the right edge, the \
one with the triangle at the bottom) --->",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Section"],

Cell[TextData[StyleBox["\t\tGNU Free Documentation License\n\t\t  Version \
1.2, November 2002\n\n\n Copyright (C) 2000,2001,2002  Free Software \
Foundation, Inc.\n     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  \
USA\n Everyone is permitted to copy and distribute verbatim copies\n of this \
license document, but changing it is not allowed.\n\n\n0. PREAMBLE\n\nThe \
purpose of this License is to make a manual, textbook, or other\nfunctional \
and useful document \"free\" in the sense of freedom: to\nassure everyone the \
effective freedom to copy and redistribute it,\nwith or without modifying it, \
either commercially or noncommercially.\nSecondarily, this License preserves \
for the author and publisher a way\nto get credit for their work, while not \
being considered responsible\nfor modifications made by others.\n\nThis \
License is a kind of \"copyleft\", which means that derivative\nworks of the \
document must themselves be free in the same sense.  It\ncomplements the GNU \
General Public License, which is a copyleft\nlicense designed for free \
software.\n\nWe have designed this License in order to use it for manuals for \
free\nsoftware, because free software needs free documentation: a free\n\
program should come with manuals providing the same freedoms that the\n\
software does.  But this License is not limited to software manuals;\nit can \
be used for any textual work, regardless of subject matter or\nwhether it is \
published as a printed book.  We recommend this License\nprincipally for \
works whose purpose is instruction or reference.\n\n\n1. APPLICABILITY AND \
DEFINITIONS\n\nThis License applies to any manual or other work, in any \
medium, that\ncontains a notice placed by the copyright holder saying it can \
be\ndistributed under the terms of this License.  Such a notice grants a\n\
world-wide, royalty-free license, unlimited in duration, to use that\nwork \
under the conditions stated herein.  The \"Document\", below,\nrefers to any \
such manual or work.  Any member of the public is a\nlicensee, and is \
addressed as \"you\".  You accept the license if you\ncopy, modify or \
distribute the work in a way requiring permission\nunder copyright law.\n\nA \
\"Modified Version\" of the Document means any work containing the\nDocument \
or a portion of it, either copied verbatim, or with\nmodifications and/or \
translated into another language.\n\nA \"Secondary Section\" is a named \
appendix or a front-matter section of\nthe Document that deals exclusively \
with the relationship of the\npublishers or authors of the Document to the \
Document's overall subject\n(or to related matters) and contains nothing that \
could fall directly\nwithin that overall subject.  (Thus, if the Document is \
in part a\ntextbook of mathematics, a Secondary Section may not explain any\n\
mathematics.)  The relationship could be a matter of historical\nconnection \
with the subject or with related matters, or of legal,\ncommercial, \
philosophical, ethical or political position regarding\nthem.\n\nThe \
\"Invariant Sections\" are certain Secondary Sections whose titles\nare \
designated, as being those of Invariant Sections, in the notice\nthat says \
that the Document is released under this License.  If a\nsection does not fit \
the above definition of Secondary then it is not\nallowed to be designated as \
Invariant.  The Document may contain zero\nInvariant Sections.  If the \
Document does not identify any Invariant\nSections then there are none.\n\n\
The \"Cover Texts\" are certain short passages of text that are listed,\nas \
Front-Cover Texts or Back-Cover Texts, in the notice that says that\nthe \
Document is released under this License.  A Front-Cover Text may\nbe at most \
5 words, and a Back-Cover Text may be at most 25 words.\n\nA \"Transparent\" \
copy of the Document means a machine-readable copy,\nrepresented in a format \
whose specification is available to the\ngeneral public, that is suitable for \
revising the document\nstraightforwardly with generic text editors or (for \
images composed of\npixels) generic paint programs or (for drawings) some \
widely available\ndrawing editor, and that is suitable for input to text \
formatters or\nfor automatic translation to a variety of formats suitable for \
input\nto text formatters.  A copy made in an otherwise Transparent file\n\
format whose markup, or absence of markup, has been arranged to thwart\nor \
discourage subsequent modification by readers is not Transparent.\nAn image \
format is not Transparent if used for any substantial amount\nof text.  A \
copy that is not \"Transparent\" is called \"Opaque\".\n\nExamples of \
suitable formats for Transparent copies include plain\nASCII without markup, \
Texinfo input format, LaTeX input format, SGML\nor XML using a publicly \
available DTD, and standard-conforming simple\nHTML, PostScript or PDF \
designed for human modification.  Examples of\ntransparent image formats \
include PNG, XCF and JPG.  Opaque formats\ninclude proprietary formats that \
can be read and edited only by\nproprietary word processors, SGML or XML for \
which the DTD and/or\nprocessing tools are not generally available, and the\n\
machine-generated HTML, PostScript or PDF produced by some word\nprocessors \
for output purposes only.\n\nThe \"Title Page\" means, for a printed book, \
the title page itself,\nplus such following pages as are needed to hold, \
legibly, the material\nthis License requires to appear in the title page.  \
For works in\nformats which do not have any title page as such, \"Title \
Page\" means\nthe text near the most prominent appearance of the work's \
title,\npreceding the beginning of the body of the text.\n\nA section \
\"Entitled XYZ\" means a named subunit of the Document whose\ntitle either is \
precisely XYZ or contains XYZ in parentheses following\ntext that translates \
XYZ in another language.  (Here XYZ stands for a\nspecific section name \
mentioned below, such as \"Acknowledgements\",\n\"Dedications\", \
\"Endorsements\", or \"History\".)  To \"Preserve the Title\"\nof such a \
section when you modify the Document means that it remains a\nsection \
\"Entitled XYZ\" according to this definition.\n\nThe Document may include \
Warranty Disclaimers next to the notice which\nstates that this License \
applies to the Document.  These Warranty\nDisclaimers are considered to be \
included by reference in this\nLicense, but only as regards disclaiming \
warranties: any other\nimplication that these Warranty Disclaimers may have \
is void and has\nno effect on the meaning of this License.\n\n\n2. VERBATIM \
COPYING\n\nYou may copy and distribute the Document in any medium, either\n\
commercially or noncommercially, provided that this License, the\ncopyright \
notices, and the license notice saying this License applies\nto the Document \
are reproduced in all copies, and that you add no other\nconditions \
whatsoever to those of this License.  You may not use\ntechnical measures to \
obstruct or control the reading or further\ncopying of the copies you make or \
distribute.  However, you may accept\ncompensation in exchange for copies.  \
If you distribute a large enough\nnumber of copies you must also follow the \
conditions in section 3.\n\nYou may also lend copies, under the same \
conditions stated above, and\nyou may publicly display copies.\n\n\n3. \
COPYING IN QUANTITY\n\nIf you publish printed copies (or copies in media that \
commonly have\nprinted covers) of the Document, numbering more than 100, and \
the\nDocument's license notice requires Cover Texts, you must enclose the\n\
copies in covers that carry, clearly and legibly, all these Cover\nTexts: \
Front-Cover Texts on the front cover, and Back-Cover Texts on\nthe back \
cover.  Both covers must also clearly and legibly identify\nyou as the \
publisher of these copies.  The front cover must present\nthe full title with \
all words of the title equally prominent and\nvisible.  You may add other \
material on the covers in addition.\nCopying with changes limited to the \
covers, as long as they preserve\nthe title of the Document and satisfy these \
conditions, can be treated\nas verbatim copying in other respects.\n\nIf the \
required texts for either cover are too voluminous to fit\nlegibly, you \
should put the first ones listed (as many as fit\nreasonably) on the actual \
cover, and continue the rest onto adjacent\npages.\n\nIf you publish or \
distribute Opaque copies of the Document numbering\nmore than 100, you must \
either include a machine-readable Transparent\ncopy along with each Opaque \
copy, or state in or with each Opaque copy\na computer-network location from \
which the general network-using\npublic has access to download using \
public-standard network protocols\na complete Transparent copy of the \
Document, free of added material.\nIf you use the latter option, you must \
take reasonably prudent steps,\nwhen you begin distribution of Opaque copies \
in quantity, to ensure\nthat this Transparent copy will remain thus \
accessible at the stated\nlocation until at least one year after the last \
time you distribute an\nOpaque copy (directly or through your agents or \
retailers) of that\nedition to the public.\n\nIt is requested, but not \
required, that you contact the authors of the\nDocument well before \
redistributing any large number of copies, to give\nthem a chance to provide \
you with an updated version of the Document.\n\n\n4. MODIFICATIONS\n\nYou may \
copy and distribute a Modified Version of the Document under\nthe conditions \
of sections 2 and 3 above, provided that you release\nthe Modified Version \
under precisely this License, with the Modified\nVersion filling the role of \
the Document, thus licensing distribution\nand modification of the Modified \
Version to whoever possesses a copy\nof it.  In addition, you must do these \
things in the Modified Version:\n\nA. Use in the Title Page (and on the \
covers, if any) a title distinct\n   from that of the Document, and from \
those of previous versions\n   (which should, if there were any, be listed in \
the History section\n   of the Document).  You may use the same title as a \
previous version\n   if the original publisher of that version gives \
permission.\nB. List on the Title Page, as authors, one or more persons or \
entities\n   responsible for authorship of the modifications in the Modified\n\
   Version, together with at least five of the principal authors of the\n   \
Document (all of its principal authors, if it has fewer than five),\n   \
unless they release you from this requirement.\nC. State on the Title page \
the name of the publisher of the\n   Modified Version, as the publisher.\nD. \
Preserve all the copyright notices of the Document.\nE. Add an appropriate \
copyright notice for your modifications\n   adjacent to the other copyright \
notices.\nF. Include, immediately after the copyright notices, a license \
notice\n   giving the public permission to use the Modified Version under the\
\n   terms of this License, in the form shown in the Addendum below.\nG. \
Preserve in that license notice the full lists of Invariant Sections\n   and \
required Cover Texts given in the Document's license notice.\nH. Include an \
unaltered copy of this License.\nI. Preserve the section Entitled \
\"History\", Preserve its Title, and add\n   to it an item stating at least \
the title, year, new authors, and\n   publisher of the Modified Version as \
given on the Title Page.  If\n   there is no section Entitled \"History\" in \
the Document, create one\n   stating the title, year, authors, and publisher \
of the Document as\n   given on its Title Page, then add an item describing \
the Modified\n   Version as stated in the previous sentence.\nJ. Preserve the \
network location, if any, given in the Document for\n   public access to a \
Transparent copy of the Document, and likewise\n   the network locations \
given in the Document for previous versions\n   it was based on.  These may \
be placed in the \"History\" section.\n   You may omit a network location for \
a work that was published at\n   least four years before the Document itself, \
or if the original\n   publisher of the version it refers to gives \
permission.\nK. For any section Entitled \"Acknowledgements\" or \
\"Dedications\",\n   Preserve the Title of the section, and preserve in the \
section all\n   the substance and tone of each of the contributor \
acknowledgements\n   and/or dedications given therein.\nL. Preserve all the \
Invariant Sections of the Document,\n   unaltered in their text and in their \
titles.  Section numbers\n   or the equivalent are not considered part of the \
section titles.\nM. Delete any section Entitled \"Endorsements\".  Such a \
section\n   may not be included in the Modified Version.\nN. Do not retitle \
any existing section to be Entitled \"Endorsements\"\n   or to conflict in \
title with any Invariant Section.\nO. Preserve any Warranty Disclaimers.\n\n\
If the Modified Version includes new front-matter sections or\nappendices \
that qualify as Secondary Sections and contain no material\ncopied from the \
Document, you may at your option designate some or all\nof these sections as \
invariant.  To do this, add their titles to the\nlist of Invariant Sections \
in the Modified Version's license notice.\nThese titles must be distinct from \
any other section titles.\n\nYou may add a section Entitled \"Endorsements\", \
provided it contains\nnothing but endorsements of your Modified Version by \
various\nparties--for example, statements of peer review or that the text has\
\nbeen approved by an organization as the authoritative definition of a\n\
standard.\n\nYou may add a passage of up to five words as a Front-Cover Text, \
and a\npassage of up to 25 words as a Back-Cover Text, to the end of the list\
\nof Cover Texts in the Modified Version.  Only one passage of\nFront-Cover \
Text and one of Back-Cover Text may be added by (or\nthrough arrangements \
made by) any one entity.  If the Document already\nincludes a cover text for \
the same cover, previously added by you or\nby arrangement made by the same \
entity you are acting on behalf of,\nyou may not add another; but you may \
replace the old one, on explicit\npermission from the previous publisher that \
added the old one.\n\nThe author(s) and publisher(s) of the Document do not \
by this License\ngive permission to use their names for publicity for or to \
assert or\nimply endorsement of any Modified Version.\n\n\n5. COMBINING \
DOCUMENTS\n\nYou may combine the Document with other documents released under \
this\nLicense, under the terms defined in section 4 above for modified\n\
versions, provided that you include in the combination all of the\nInvariant \
Sections of all of the original documents, unmodified, and\nlist them all as \
Invariant Sections of your combined work in its\nlicense notice, and that you \
preserve all their Warranty Disclaimers.\n\nThe combined work need only \
contain one copy of this License, and\nmultiple identical Invariant Sections \
may be replaced with a single\ncopy.  If there are multiple Invariant \
Sections with the same name but\ndifferent contents, make the title of each \
such section unique by\nadding at the end of it, in parentheses, the name of \
the original\nauthor or publisher of that section if known, or else a unique \
number.\nMake the same adjustment to the section titles in the list of\n\
Invariant Sections in the license notice of the combined work.\n\nIn the \
combination, you must combine any sections Entitled \"History\"\nin the \
various original documents, forming one section Entitled\n\"History\"; \
likewise combine any sections Entitled \"Acknowledgements\",\nand any \
sections Entitled \"Dedications\".  You must delete all sections\nEntitled \
\"Endorsements\".\n\n\n6. COLLECTIONS OF DOCUMENTS\n\nYou may make a \
collection consisting of the Document and other documents\nreleased under \
this License, and replace the individual copies of this\nLicense in the \
various documents with a single copy that is included in\nthe collection, \
provided that you follow the rules of this License for\nverbatim copying of \
each of the documents in all other respects.\n\nYou may extract a single \
document from such a collection, and distribute\nit individually under this \
License, provided you insert a copy of this\nLicense into the extracted \
document, and follow this License in all\nother respects regarding verbatim \
copying of that document.\n\n\n7. AGGREGATION WITH INDEPENDENT WORKS\n\nA \
compilation of the Document or its derivatives with other separate\nand \
independent documents or works, in or on a volume of a storage or\n\
distribution medium, is called an \"aggregate\" if the copyright\nresulting \
from the compilation is not used to limit the legal rights\nof the \
compilation's users beyond what the individual works permit.\nWhen the \
Document is included in an aggregate, this License does not\napply to the \
other works in the aggregate which are not themselves\nderivative works of \
the Document.\n\nIf the Cover Text requirement of section 3 is applicable to \
these\ncopies of the Document, then if the Document is less than one half of\n\
the entire aggregate, the Document's Cover Texts may be placed on\ncovers \
that bracket the Document within the aggregate, or the\nelectronic equivalent \
of covers if the Document is in electronic form.\nOtherwise they must appear \
on printed covers that bracket the whole\naggregate.\n\n\n8. TRANSLATION\n\n\
Translation is considered a kind of modification, so you may\ndistribute \
translations of the Document under the terms of section 4.\nReplacing \
Invariant Sections with translations requires special\npermission from their \
copyright holders, but you may include\ntranslations of some or all Invariant \
Sections in addition to the\noriginal versions of these Invariant Sections.  \
You may include a\ntranslation of this License, and all the license notices \
in the\nDocument, and any Warranty Disclaimers, provided that you also \
include\nthe original English version of this License and the original \
versions\nof those notices and disclaimers.  In case of a disagreement \
between\nthe translation and the original version of this License or a notice\
\nor disclaimer, the original version will prevail.\n\nIf a section in the \
Document is Entitled \"Acknowledgements\",\n\"Dedications\", or \"History\", \
the requirement (section 4) to Preserve\nits Title (section 1) will typically \
require changing the actual\ntitle.\n\n\n9. TERMINATION\n\nYou may not copy, \
modify, sublicense, or distribute the Document except\nas expressly provided \
for under this License.  Any other attempt to\ncopy, modify, sublicense or \
distribute the Document is void, and will\nautomatically terminate your \
rights under this License.  However,\nparties who have received copies, or \
rights, from you under this\nLicense will not have their licenses terminated \
so long as such\nparties remain in full compliance.\n\n\n10. FUTURE REVISIONS \
OF THIS LICENSE\n\nThe Free Software Foundation may publish new, revised \
versions\nof the GNU Free Documentation License from time to time.  Such new\n\
versions will be similar in spirit to the present version, but may\ndiffer in \
detail to address new problems or concerns.  See\n\
http://www.gnu.org/copyleft/.\n\nEach version of the License is given a \
distinguishing version number.\nIf the Document specifies that a particular \
numbered version of this\nLicense \"or any later version\" applies to it, you \
have the option of\nfollowing the terms and conditions either of that \
specified version or\nof any later version that has been published (not as a \
draft) by the\nFree Software Foundation.  If the Document does not specify a \
version\nnumber of this License, you may choose any version ever published \
(not\nas a draft) by the Free Software Foundation.\n\n\nADDENDUM: How to use \
this License for your documents\n\nTo use this License in a document you have \
written, include a copy of\nthe License in the document and put the following \
copyright and\nlicense notices just after the title page:\n\n    Copyright \
(c)  YEAR  YOUR NAME.\n    Permission is granted to copy, distribute and/or \
modify this document\n    under the terms of the GNU Free Documentation \
License, Version 1.2\n    or any later version published by the Free Software \
Foundation;\n    with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.\n    A copy of the license is included in the section \
entitled \"GNU\n    Free Documentation License\".\n\nIf you have Invariant \
Sections, Front-Cover Texts and Back-Cover Texts,\nreplace the \
\"with...Texts.\" line with this:\n\n    with the Invariant Sections being \
LIST THEIR TITLES, with the\n    Front-Cover Texts being LIST, and with the \
Back-Cover Texts being LIST.\n\nIf you have Invariant Sections without Cover \
Texts, or some other\ncombination of the three, merge those two alternatives \
to suit the\nsituation.\n\nIf your document contains nontrivial examples of \
program code, we\nrecommend releasing these examples in parallel under your \
choice of\nfree software license, such as the GNU General Public License,\nto \
permit their use in free software.\n",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1625}, {0, 1028}},
WindowSize->{961, 713},
WindowMargins->{{Automatic, 111}, {Automatic, 51}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 0, 88, "Title"],
Cell[1846, 55, 499, 7, 94, "Text"],

Cell[CellGroupData[{
Cell[2370, 66, 28, 0, 69, "Section"],
Cell[2401, 68, 379, 8, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2817, 81, 51, 0, 69, "Section"],
Cell[2871, 83, 487, 11, 50, "Text"],
Cell[3361, 96, 174, 3, 43, "Input"],
Cell[3538, 101, 118, 3, 30, "Text"],
Cell[3659, 106, 167, 3, 59, "Input"],
Cell[3829, 111, 664, 13, 97, "Text"],
Cell[4496, 126, 546, 8, 139, "Input"],
Cell[5045, 136, 420, 8, 79, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5502, 149, 90, 3, 69, "Section"],
Cell[5595, 154, 278, 7, 59, "Input"],

Cell[CellGroupData[{
Cell[5898, 165, 63, 0, 38, "Subsection"],
Cell[5964, 167, 250, 5, 46, "Text"],
Cell[6217, 174, 1191, 25, 267, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7445, 204, 57, 0, 38, "Subsection"],
Cell[7505, 206, 479, 8, 62, "Text"],
Cell[7987, 216, 2697, 47, 603, "Input"],
Cell[10687, 265, 253, 6, 32, "Text"],
Cell[10943, 273, 207, 5, 43, "Input"],
Cell[11153, 280, 69, 0, 30, "Text"],
Cell[11225, 282, 422, 8, 75, "Input"],
Cell[11650, 292, 92, 3, 30, "Text"],
Cell[11745, 297, 910, 18, 155, "Input"],
Cell[12658, 317, 630, 15, 63, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13337, 338, 29, 0, 69, "Section"],
Cell[13369, 340, 812, 18, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14218, 363, 260, 4, 101, "Section"],
Cell[14481, 369, 21527, 282, 7974, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

